%% *************************************************************************
%
% Environmental Systems Analysis with Matlab 
% S. Marsili-Libelli
%
%  CRC Press 2016
% ISBN 9781498706353
% Matlab code revised by Emanuele El Basri and Giacomo Barni
% *************************************************************************
% 
% Comparing the solutions of 
% the Logistic equation:
% Direct solution with the
% Matlab solver ODE45
% vs.
% Simulink solution
%
%% *************************************************************************


clear
close all

global r K    % make r and K visible to Logist function
t0=0;tfin=40; % Simulation interval
K=10;         % Carrying capacity
x0 = 0.5;     % Initial population

figure(1)
set(1,'Position',[15 62 750 459])
% Call the ODE solver in the loop
tic
for r=0.2:0.1:0.4
[t,x] = ode45('logist',[t0 tfin], x0);
subplot(121)
plot(t,x)
set(gca, 'FontName','Arial', 'FontSize',11)
hold on
end
toc
% Plot the results 
xlabel('time')
ylabel('population')
title('Logistic equation with ODE45 solver')

% Simulink solver in the loop
tic
for r=0.2:0.1:0.4
[t,x,y]=sim('Logistic_model',[t0 tfin]);
subplot(122)
plot(t,x)
set(gca, 'FontName','Arial', 'FontSize',11)
hold on
end
toc
title('Logistic equation with Simulink solver')
xlabel('time')
ylabel('population')