% *************************************************************************
%
% Environmental Systems Analysis with Matlab 
% S. Marsili-Libelli
%
%  CRC Press 2016
% ISBN 9781498706353
% Matlab code revised by Emanuele El Basri and Giacomo Barni
% *************************************************************************
% 
% This exercise considers a simple reservoir model with surface outflow
% 
% Exercise 1.11.2, Eq. (1.117), Box 1.8, and Figure 1.61
%
% *************************************************************************

clear
close all
clc

%% Load data
g = uigetfile('Flow*.mat', 'Load calibration data');
eval(['load ' g]);
Cr = input('Insert number of cyclic repetitions: ');

% Define odel parameters
% Vo = 557;       % Volume                                            [m^3]
alfa = 2.4e-2;    % Flow coefficient
n    = 0.875;     % Flow exponent

ts = Portata(:,1);
q  = Portata(:,2);

Ts = ts;
Q  = q;
if Cr > 1,
    for j = 1:Cr
      Ts = [Ts; ts + Ts(end)];
      Q  = [Q; q];
    end
end

Fb   = mean(Q); % Mean input flow
Vo   = exp((log(Fb) - log(alfa))/n); % Steady state volume
tfin = Ts(end);
Portata = [Ts Q];

%% Launch the simulation
[t, x, y] = sim('Lake_volume', tfin);

%% Figures
figure(1)
set(1, 'Position', [15 62 866 459])
set(gca, 'FontName','Arial', 'FontSize',12)

subplot(211)
plot(t,F_input,':b', t,F_output,'b', 'LineWidth',2)
set(gca, 'FontName','Arial', 'FontSize',12)
legend('Input flow', 'Output flow', 'location','northoutside',...
       'orientation','horizontal')
ylabel('Flow [m^3/d]')

subplot(212)
plot(t, Volume, 'LineWidth',2)
set(gca, 'FontName','Arial', 'FontSize',12)
ylabel('Volume [m^3]')
xlabel('time [d]')

