% *************************************************************************
%
% Environmental Systems Analysis with Matlab 
% S. Marsili-Libelli
%
%  CRC Press 2016
% ISBN 9781498706353
% Matlab code revised by Emanuele El Basri and Giacomo Barni
% *************************************************************************
% 
% Matlab script for Exercise 1.11.4, time evolution of a discrete-time
% system
%
% *************************************************************************

clc
clear
close all

%% System matrix
A = [0.2, 0.3;
      -5, 0.1]; 
disp('Eigenvalues and Eigenvectors')
[v, e] = eig(A)

%% System definition
u = 6.15;      % Constant input
b = [0 1]';
t = 0;
x = [1 -0.5]'; % Initial conditions
xo = x;

%% Simulation loop
X = [];
T = [];
while t < 20        
    x_t1 = A*x + b*u;
    X = [X; x'];
    x = x_t1;
    T = [T t];
    t = t+1;  
end

%% Computation of the final equilibrium
I2 = eye(2);
A1 = inv(I2 - A);
x_eq = A1*b*u

%% Figures
figure(1)
set(1,'Position',[15 62 520 400])
plot(X(:,1), X(:,2), '-ob','MarkerFaceColor','b','MarkerSize',8)
hold on
plot(x_eq(1) ,x_eq(2), 'sr', 'MarkerSize',10, 'MarkerFaceColor','y')
xlabel('x_1')
ylabel('x_2')
legend('State trajectory','Steady-state')