%% *************************************************************************
%
% Environmental Systems Analysis with Matlab 
% S. Marsili-Libelli
%
%  CRC Press 2016
% ISBN 9781498706353
% Matlab code revised by Emanuele El Basri and Giacomo Barni
% *************************************************************************
% 
% Matlab script for the Monod model
%
% Sect. 1.10.4.1, Eq. (1.113), and Figure 1.55
%
%% *************************************************************************

clc
clear
close all

% Nominal kinetic parameter values
Ks=20;Y=0.5;Mu=0.5;bH=0.03;
% Batch simulation horizon
tfin=150;
% Initial conditions
So=10;Xo=0.1;
% Launch the simulation
[t,x,y]=sim('Monod',[0 tfin]);
figure(1)
set(1, 'Position', [15 62 866 459])
set(gca, 'FontName','Arial', 'FontSize',12)
plot(t,S,'b',t,X,':r','LineWidth',2)
xlabel('time (h)')
ylabel('Concentration (mg/l)')
legend('Substrate','Biomass')