%% ************************************************************************
%
% Environmental Systems Analysis with Matlab 
% S. Marsili-Libelli
%
%  CRC Press 2016
% ISBN 9781498706353
% Matlab code revised by Emanuele El Basri and Giacomo Barni
% *************************************************************************
%
% Launch script for the Nash reservoir model
% where the driving pulse is approximated by the difference of two
% subsequent steps
%
% Sect. 1.8.3.1
%
%% ************************************************************************

clear
close all
clc

    
ta=0.1;   % Rainfall duration up to ta
u=1/ta;    % Rainfall amout, reciprocal to the duration ta
tfin=1000; % Simulation time
           % Zero initial conditions
figure(1)
set(1,'Position',[27 55 560 420])
set(gca,'FontName','Arial','FontSize',12)
for k=0.01:0.01:0.04  % k represents the single reservoir time constant
    % Define system matrix
A=[-k 0 0 0 0;k -k 0 0 0;0 k -k 0 0; 0 0 k -k 0;0 0 0 k -k];
    % Define input matrix
b=[1 0 0 0 0]';
    % Define ouput matrix
c=[0 0 0 0 k];
[t,x,y]=sim('Nash_approx',tfin);
plot(t,q)
% put legends
Ihh=find(q>0.85*max(q));
Ih=Ihh(end);
th=t(Ih);
text(th,q(Ih),['    k = ',num2str(k)])
hold on
end
xlabel('time (h)')
ylabel('discharge (m^3 s^-^1)')
title('Discharge impulse response (Unit Hydrograph)')
axis tight

figure(2)
set(2,'Position',[605 55 560 420])
set(gca,'FontName','Arial','FontSize',12)
plot(t,x)
legend('x_1','x_2','x_3','x_4','x_5')
axis([0 400 0 1])
xlabel('time (h)')
ylabel('reservoir volum (m^3)')
title('Volume of each reservoir')