% *************************************************************************
%
% Environmental Systems Analysis with Matlab 
% S. Marsili-Libelli
%
%  CRC Press 2016
% ISBN 9781498706353
% Matlab code revised by Emanuele El Basri and Giacomo Barni
% *************************************************************************
% 
% Two-reach Streeter & Phelps water quality modelling
% 
% Matlab launch script for Exercise 1.11.5
%
% *************************************************************************

clear
close all
clc

prompt = {'Upstream flow [m^3/s]',...
          'Upstream BOD [mg/L]',...
          'Upstream DO [mg/L]',...
          'Upstream discharge flow [m^3/s]',...
          'Upstream discharge BOD [mg/L]',...
          'Upstream discharge DO [mg/L]',...
          'DO Saturation [mg/L]'};
def  = {'5', '3', '8', '0.5', '30', '0', '8'}; % Default values
data = inputdlg(prompt,'Upstream loading conditions',1,def,'on');
data = char(data);

Qm   = str2num(data(1,:));
Bm   = str2num(data(2,:));
Cm   = str2num(data(3,:));
Qs   = str2num(data(4,:));
Bs   = str2num(data(5,:));
Cs   = str2num(data(6,:));
Csat = str2num(data(7,:));

%% Upstream initial conditions
Q1 = Qm + Qs
Bo = (Bm*Qm + Qs*Bs)/Q1
Co = (Cm*Qm + Cs*Qs)/Q1
prompt = {'Kb [1/h]',...
          'Kc [1/h]',...
          'Reach total length [h]',...
          'Second discharge location [h]',...
          'Second discharge flow [m^3/s]',...
          'Second discharge BOD [mg/L]',...
          'Second discharge DO [mg/L]'};
def  = {'0.12', '0.15', '40', '15', '0.35', '20', '2'};
data = inputdlg(prompt, 'River system parameters', 1, def, 'on');
data = char(data);

Kb  = str2num(data(1,:));
Kc  = str2num(data(2,:));
L   = str2num(data(3,:)); 
ts2 = str2num(data(4,:));
Qs2 = str2num(data(5,:)); 
Bs2 = str2num(data(6,:));
Cs2 = str2num(data(7,:));

%% Run simulation
%  Simulation of the first reach
Boo = Bo;
Coo = Co; % Save upstream conditions for later
[tsim,x,y] = sim('SP_reach', [0 ts2]);
last = length(tsim);
BOD1 = BOD;
DO1  = DO;
t1   = tsim;
B1   = BOD(last)
C1   = DO(last)

%  Second discharge mixing
Qm1  = Qm + Qs
Bo   = (B1*Qm1 + Qs2*Bs2)/(Qm1 + Qs2)
Co   = (C1*Qm1 + Cs2*Qs2)/(Qm1 + Qs2)

%  Simulation of the second reach
[tsim, x, y] = sim('SP_reach', [0 L-ts2]);
last     = length(tsim);
B_finale = BOD(last)
C_finale = DO(last)

%% Combining the two reaches
BOD  = [BOD1' BOD'];
DO   = [DO1' DO'];
tsim = [t1' (tsim + ts2)'];

%% Figures
figure(1)
set(1,'Position',[15 62 750 459])
plot(tsim,BOD,':b', tsim,DO,'b', 'LineWidth',2)
set(gca, 'FontName','Arial', 'FontSize',11)
a = axis;
axis([a(1) a(2) 0 Csat+1])
xlabel('Reach length [h]')
ylabel('Concentration [mg/L]')
hold on
plot([0 L], [Csat Csat], ':b')
plot(0, Boo, 'sb', 'MarkerSize',8, 'MarkerFaceColor','b')
text(0, Boo, ['  ',num2str(Boo)], 'vert','bottom','hor','left')
plot(0, Coo, 'ob', 'MarkerSize',8, 'MarkerFaceColor','b')
text(0, Coo, ['  ',num2str(Coo)], 'vert','bottom','hor','left')
plot(ts2, B1, 'sb', 'MarkerSize',8, 'MarkerFaceColor','b')
text(ts2, B1, [num2str(B1),'  '], 'vert','top','hor','right')
plot(ts2, C1, 'ob', 'MarkerSize',8, 'MarkerFaceColor','b')
text(ts2, C1, ['  ',num2str(C1)], 'hor','left','vert','bottom')
plot(ts2, Bo, 'sb', 'MarkerSize',8, 'MarkerFaceColor','b')
text(ts2, Bo, ['  ',num2str(Bo)], 'hor','left','vert','bottom')
plot(ts2, Co, 'ob', 'MarkerSize',8, 'MarkerFaceColor','b')
text(ts2, Co,[num2str(Co),'  '], 'hor','right','vert','top')
plot(max(tsim), B_finale, 'sb', 'MarkerSize',8,'MarkerFaceColor','b')
text(max(tsim), B_finale, ['  ',num2str(B_finale)], 'hor','left','vert','bottom')
plot(max(tsim), C_finale, 'ob', 'MarkerSize',8, 'MarkerFaceColor','b')
text(max(tsim), C_finale, ['  ',num2str(C_finale)], 'hor','left','vert','bottom')
legend('BOD', 'DO', 'C_{sat}', 'location','east')
