% *************************************************************************
%
% Environmental Systems Analysis with Matlab 
% S. Marsili-Libelli
%
%  CRC Press 2016
% ISBN 9781498706353
% Matlab code revised by Emanuele El Basri and Giacomo Barni
% *************************************************************************
% 
% Single-reach Streeter & Phelps water quality modelling with a non-point 
% pollution part
% 
% Matlab launch script for Exercise 1.11.6
%
% *************************************************************************

clear
close all
clc

prompt = {'Upstream BOD [mg/L]',...
          'Upstream DO [mg/L]',...
          'DO Saturation [mg/L]',...
          'Upstream flow [m^3/s]',...
          'Upstream discharge flow [m^3/s]',...
          'Upstream discharge BOD [mg/L]',...
          'Upstream discharge DO [mg/L]',...
          'Kb BOD decay rate [1/h]',...
          'Kc Reaeration rate [1/h]',...
          'Final flow time [h]',...
          'Initial non-point BOD flow time [h]',...
          'Final non-point BOD flow time [h]',...
          'Non-point BOD value [mg/L*h]'};
def  = {'10.0', '7.0', '8', '5.0', '1.0', '40', '0', '0.1', '0.15',...
        '40', '20', '30', '0.6'};
data = inputdlg(prompt, 'River system definition', 1, def,'on');
data = char(data);

Bm   = str2num(data(1,:));
Cm   = str2num(data(2,:));
Csat = str2num(data(3,:));
Qm   = str2num(data(4,:));
Qs   = str2num(data(5,:));
Bs   = str2num(data(6,:));
Cs   = str2num(data(7,:));

% Initial BOD
Bo = (Qm*Bm + Qs*Bs)/(Qm + Qs);

% Initial DO
Co   = (Cm*Qm + Cs*Qs)/(Qm + Qs);
Kb   = str2num(data(8,:));
Kc   = str2num(data(9,:));
tfin = str2num(data(10,:));
T1   = str2num(data(11,:)); 
Tf   = str2num(data(12,:)); 
Bu   = str2num(data(13,:));

%% Run simulation
[tsim, x, y] = sim('SP_distr_const', tfin);

BOD1 = interp1(tsim, BOD, T1)
DO1  = interp1(tsim, DO,  T1)
Bf = BOD(length(BOD));
Cf = DO(length(DO));

%% Figures
figure(1)
set(1,'Position',[15 62 750 459])
plot(tsim,BOD,':b', tsim,DO,'b')
set(gca, 'FontName','Arial', 'FontSize',11)
a = axis;
axis([0 tfin+1 0 max(Csat+1,Bo+1)])
xlabel('Flow time [h]')
ylabel('Concentration [mg/L]')
hold on
plot([0 tfin], [Csat Csat], '--b')
fill(tsim, BODin, [223/255 233/255 0.999])
legend('BOD', 'DO', 'C_{sat}','non-point BOD')
title('Non-point BOD Streeter & Phelps model')

plot(0, Bo, 'sb', 'MarkerSize',8, 'MarkerFaceColor','b')
text(0, Bo, ['  ',num2str(Bo)], 'vert','bottom')

plot(T1, BOD1, 'sb', 'MarkerSize',8, 'MarkerFaceColor','b')
text(T1, BOD1, [num2str(BOD1),'  '], 'vert','bottom','hor','right')

plot(T1, DO1, 'ob', 'MarkerSize',8, 'MarkerFaceColor','b')
text(T1, DO1, [num2str(DO1),'  '], 'vert','bottom','hor','right')

plot(0, Co, 'ob', 'MarkerSize',8, 'MarkerFaceColor','b')
text(0, Co, ['  ',num2str(Co)], 'vert','bottom')

plot(tfin, Bf, 'sb', 'MarkerSize',8, 'MarkerFaceColor','b')
text(tfin, Bf, [num2str(Bf),'  '], 'vert','bottom','hor','right')

plot(tfin,Cf,'ob','MarkerSize',8,'MarkerFaceColor','b')
text(tfin,Cf,[num2str(Cf),'  '],'vert','bottom','hor','right')