% *************************************************************************
%
% Environmental Systems Analysis with Matlab 
% S. Marsili-Libelli
%
%  CRC Press 2016
% ISBN 9781498706353
% Matlab code revised by Emanuele El Basri and Giacomo Barni
% *************************************************************************
% 
% Run Streeter & phelps model.
% 
% Reference to the exercise goes here
%
% *************************************************************************

clear
close all

Csat = 8;
Kb   = 0.12;
Kc   = 0.15;
ts   = 50;

%% Compute initial conditions
Bo = 8;
Co = 8;

%% Run simulation
[tsim, x, y] = sim('SP_reach', [0 ts]);

%% Figures
figure(1)
set(1,'Position',[15 62 750 459])
plot(tsim,BOD,'r', tsim,DO,'b', tsim,reox,'.-b')
set(gca, 'FontName','Arial', 'FontSize',11)
a = axis;
axis([a(1) a(2) a(3) Csat+1])
xlabel('Length (h)')
ylabel('Concentration [mg-O_2/L]')
hold on
plot([0 ts], [Csat Csat], ':b')
legend('BOD', 'DO','re-oxigenation', 'C_{sat}','location','east' )