% *************************************************************************
%
% Environmental Systems Analysis with Matlab
% S. Marsili-Libelli
%
%  CRC Press 2016
% ISBN 9781498706353
% Matlab code revised by Emanuele El Basri and Giacomo Barni
% *************************************************************************
%
% Static sensitivity computation for the
% four parameters of the batch Monod model.
%
% Sect. 2.2.1.1 and Fig. 2.7
%
% *************************************************************************

clear
close all
clc
%%
% Definition of model parameters

Mu=0.5;
Ks=40;
Y=0.5;
bH=0.03;
tfin=200;

So=10;Xo=0.1; % Initial conditions


[t,x,y]=sim('Monod',[0 tfin]); % Model simulation
t_nom=t;
S_nom=S;
X_nom=X;

figure(1)
set(1,'Position',[35 49 613 479])
plot(t,S_nom,'b',t,X_nom,':r','LineWidth',2)
set(gca,'FontName','Arial','FontSize',12)
xlabel('time (h)')
ylabel('Concentration (mg/l)')
legend('Substrate','Biomass')
%% ---- Sensitivity computation ----
% Static sensitivity to Mu_max
%
MMu=[];DDE=[];
for Mu=0.3:0.05:1.25
    MMu=[MMu Mu];
    [t,x,y]=sim('Monod',[0 tfin]); % Simulazione
    DE=sum((S-S_nom).^2)+sum((S-X_nom).^2);
    DDE=[DDE DE];
end

figure(2)
set(2,'Position',[665 50 560 478])
subplot(221)
% Plot sensitivity to Mu_max
plot(MMu,DDE,'-ob','MarkerFaceColor','b')
xlabel('{\mu}_m_a_x')
ylabel('{\Delta}E')
axis tight
% Reinitialize parameter at their nominal values
Mu=0.5;
Ks=40;
Y=0.5;
bH=0.03;
%%
% Static sensitivity to Ks
KKs=[];DDKs=[];
for Ks=10:5:100
    KKs=[KKs Ks];
    [t,x,y]=sim('Monod',[0 tfin]); % Simulazione
    Ds=sum((S-S_nom).^2)+sum((X-X_nom).^2);
    DDKs=[DDKs Ds];
end

subplot(222)
% Plot sensitivity to Ks
plot(KKs,DDKs,'-ob','MarkerFaceColor','b')
xlabel('K_s')
ylabel('{\Delta}E')
axis tight
% Reinitialize parameter at their nominal values
Mu=0.5;
Ks=40;
Y=0.5;
bH=0.03;
%%
% Static sensitivity to Y
YY=[];DEY=[];
for Y=0.2:0.05:0.8
    YY=[YY Y];
    [t,x,y]=sim('Monod',[0 tfin]); % Simulazione
    Ds=sum((S-S_nom).^2)+sum((X-X_nom).^2);
    DEY=[DEY Ds];
end
% Plot sensitivity to Y
subplot(223)
plot(YY,DEY,'-ob','MarkerFaceColor','b')
xlabel('Y')
ylabel('{\Delta}E')
axis tight
% Reinitialize parameter at their nominal values
Mu=0.5;
Ks=40;
Y=0.5;
bH=0.03;
%%
% Static sensitivity to bh
BBh=[];DEbh=[];
for bH=0.005:0.005:0.05
    BBh=[BBh bH];
    [t,x,y]=sim('Monod',[0 tfin]); % Simulazione
    Ds=sum((S-S_nom).^2)+sum((X-X_nom).^2);
    DEbh=[DEbh Ds];
end
% Plot sensitivity to bH
subplot(224)
plot(BBh,DEbh,'-ob','MarkerFaceColor','b')
xlabel('b_H')
ylabel('{\Delta}E')
axis tight

