% *************************************************************************
%
% Environmental Systems Analysis with Matlab
% S. Marsili-Libelli
%
%  CRC Press 2016
% ISBN 9781498706353
% Matlab code revised by Emanuele El Basri and Giacomo Barni
% *************************************************************************
%
% This exercise demonstrates the PCA reconstruction with full or reduced
% dimension. The data refer to the Arno River water quality.
%
% Sect. 3.5.2
%
% *************************************************************************

clear
close all
clc

%% Load data
Ros_Data = xlsread('Ros_Sett.xls');

%% Centre and scale the input data
Xz = zscore(Ros_Data);
[n p] = size(Xz);

%% Dimension reduction (a < p)
for a=3:-1:1
    [S, scores, eig, t2] = princomp(Xz);
    [residuals, reconstructed] = pcares(Xz, a);
    Sa = S(:,[1:a]); % Retain the first a columns of the PCA
    scoresa = Xz*Sa;
	
	%  Plot the data reconstructed using the first a components
    figure(a)
    clf
    subplot(311)
    plot([1:n], Xz(:,1), 'b', [1:n], reconstructed(:,1), ':+b')
    ylabel('DO stand.')
    axis tight
    title(['Reconstruction with a = ', num2str(a)])
    subplot(312)
    plot([1:n], Xz(:,2), 'r', [1:n], reconstructed(:,2), ':+r')
    ylabel('pH stand.')
    axis tight
    subplot(313)
    plot([1:n], Xz(:,3), 'k', [1:n], reconstructed(:,3), ':+k')
    ylabel('T stand.')
    axis tight
end