% *************************************************************************
%
% Environmental Systems Analysis with Matlab
% S. Marsili-Libelli
%
%  CRC Press 2016
% ISBN 9781498706353
% Matlab code revised by Emanuele El Basri and Giacomo Barni
% *************************************************************************
%
% This exercise demonstrates the PCA reconstruction of a random time-series
% with varying dimension of the reconstruction space.
%
% Sect. 3.5.2
%
% *************************************************************************

clear
close all
clc
%%
N = 100;
p = 3; % Number of features

% Generate the input values
%  Random observations (with unit variance)
X = zeros(N, p);
for i = 1:N-1
    e = randn(1);
    X(i+1,1) = 0.85*X(i,2) - 0.55*e;
    X(i+1,2) = 0.74*X(i,1) + 0.85*e;
    X(i+1,3) = 0.2*X(i,1)  - 0.53*X(i,2) - 0.2*X(i,3) - 0.4*e;
end

%  Compute the average
XM=mean(X);
%  Substract the average
X(:,1) = X(:,1) - XM(1);
X(:,2) = X(:,2) - XM(2);
X(:,3) = X(:,3) - XM(3);

%% PCA on the standardized data
[P, Z, L, T2] = princomp(X); % Zero-mean Raw data PCA
Xr3 = Z*P'; % Reduced reconstruction of order 3
Xr2 = Z(:,1:2)*P(:,1:2)'; % Reduced reconstruction of order 2
Xr1 = Z(:,1)*P(:,1)'; % Reduced reconstruction of order 1

%% Figures
figure(1)
set(1, 'Position',[40 108 1110 477])

%  Reduction a = 3
M = 4;   % Plot y-limit
mm = 12; % Font size
subplot(331)
plot(X(:,1), '.')
hold on
plot(Xr3(:,1), ':r')
plot([0 N], [0 0], 'k')
set(gca, 'FontName','Arial', 'FontSize',mm)
% xlabel('sample')
ylabel('x_1')
title('a = 3')
axis([0 100 -M M])

subplot(334)
plot(X(:,2),'.')
hold on
plot(Xr3(:,2),':r')
plot([0 N],[0 0],'k')
set(gca,'FontName','Arial','FontSize',mm)
% xlabel('sample')
ylabel('x_2')
axis([0 100 -M M])

subplot(337)
plot(X(:,3), '.')
hold on
plot(Xr3(:,3), ':r')
plot([0 N], [0 0], 'k')
set(gca, 'FontName','Arial', 'FontSize',mm)
xlabel('sample')
ylabel('x_3')
axis([0 100 -M M])

%  Reduction a = 2
subplot(332)
plot(X(:,1), '.')
hold on
plot(Xr2(:,1), ':r')
plot([0 N], [0 0],'k')
set(gca, 'FontName','Arial', 'FontSize',mm)
% xlabel('sample')
ylabel('x_1')
title('a = 2')
axis([0 100 -M M])

subplot(335)
plot(X(:,2), '.')
hold on
plot(Xr2(:,2), ':r')
plot([0 N], [0 0], 'k')
set(gca, 'FontName','Arial', 'FontSize',mm)
% xlabel('sample')
ylabel('x_2')
axis([0 100 -M M])

subplot(338)
plot(X(:,3),'.')
hold on
plot(Xr2(:,3),':r')
plot([0 N],[0 0],'k')
set(gca,'FontName','Arial','FontSize',mm)
xlabel('sample')
ylabel('x_3')
axis([0 100 -M M])

%  Reduction a = 1
subplot(333)
plot(X(:,1), '.')
hold on
plot(Xr1(:,1), ':r')
plot([0 N], [0 0], 'k')
set(gca,  'FontName','Arial', 'FontSize',mm)
% xlabel('sample')
ylabel('x_1')
title('a = 1')
axis([0 100 -M M])

subplot(336)
plot(X(:,2), '.')
hold on
plot(Xr1(:,2), ':r')
plot([0 N], [0 0], 'k')
set(gca, 'FontName','Arial', 'FontSize',mm)
ylabel('x_2')
axis([0 100 -M M])

subplot(339)
plot(X(:,3), '.')
hold on
plot(Xr1(:,3), ':r')
plot([0 N], [0 0], 'k')
set(gca, 'FontName','Arial', 'FontSize',mm)
xlabel('sample')
ylabel('x_3')
axis([0 100 -M M])

%% Biplot
%  3D biplot
figure(2)
vl={' x_1', ' x_2', ' x_3'};
biplot(P, 'Scores', Z, 'Varlabels',vl)
%  2D biplot
figure(4)
biplot(P(:,1:2), 'Scores', Z(:,1:2), 'Varlabels',vl)
scree(L, 5)

%% PCA on the covariance matrix
A = cov(X);
[Pc, Lc, explVar] = pcacov(A)