% *************************************************************************
% 
% Environmental Systems Analysis with Matlab 
% S. Marsili-Libelli
%
%  CRC Press 2016
% ISBN 9781498706353
% Matlab code revised by Emanuele El Basri and Giacomo Barni
% *************************************************************************
%
% Computation of aliased frequency.
%
% Sect. 3.2.1.1
% 
% *************************************************************************
 
clear
close all
clc

%% Set frequency parameters
fs = 1; % Sampling frequency
f  = 1.33; % Sine freq

%% Alias frequency
fa = mod(f+fs/2,fs)-fs/2;
% Alias period
Ta = 1/fa; 
Tmax = 4;
t = 0:0.01:Tmax;
y = sin(2*pi*f*t);

%% Figures
figure(1)
set(1,'Position',[23 63 560 420])
plot(t, y, 'b', 'LineWidth',2) % Trace the original sinusoid
set(gca, 'FontName','Arial', 'FontSize',12)
hold on
t1 = 0:1/fs:Tmax;     % Set the sampling times
y1 = sin(2*pi*f*t1);  % Indicate the samples along the original sinusoid
plot(t1, y1, 'sk', 'MarkerFaceColor','g', 'MarkerSize',10)

y2 = sin(2*pi*fa*t1); % Indicate the samples along the aliased sinusoid
plot(t1, y2, 'o', 'MarkerFaceColor','b', 'MarkerSize',6')

y3 = sin(2*pi*fa*t);    % Trace the whole aliased sinusoid
plot(t, y3, '--r', 'LineWidth',3)

title('Aliasing')
xlabel('Time')
ylabel('Amplitude')