% *************************************************************************
% 
% Environmental Systems Analysis with Matlab 
% S. Marsili-Libelli
%
%  CRC Press 2016
% ISBN 9781498706353
% Matlab code revised by Emanuele El Basri and Giacomo Barni
% *************************************************************************
%
% This exercise demonstrates the Wavelet Denoising property 
% by comparing several thersholding methods.
%
% Sect. 3.4.2
%
% *************************************************************************

clear
close all
clc

load DO_apr
x=DO_apr(1:24*7);

% De-noise noisy signal using soft heuristic SURE thresholding and scaled
% noise option, on detail coefficients obtained from the decomposition
% of x, at level 5 by Discrete Meyer wavelet.
lev = 5;
wname = 'dmey';  % Discrete Meyer wavelet
hs = 's';

% Plot signals. 
figure(1)
set(1,'Position',[22 49 540 649])
clf
subplot(511)
plot(x)
axis([0 length(x) 5 15])
title('Original signal')
ylabel('DO [mg/L]')

subplot(512)
xd = wden(x, 'rigrsure', hs, 'one', lev, wname);
plot(xd)
res1 = x - xd;
axis([0 length(x) 5 15])
title('De-noised signal - Unbiased Risk')
ylabel('DO [mg/L]')

%% Denoised heuristic SURE
subplot(513)
xd = wden(x, 'heursure', hs, 'one', lev, wname);
res2 = x - xd;
plot(xd)
axis([0 length(x) 5 15])
title('De-noised signal - Heuristic SURE')
ylabel('DO [mg/L]')

%% De-noise noisy signal using soft SURE thresholding 
subplot(514)
%  De-noise noisy signal using fixed form threshold with 
%  a single level estimation of noise standard deviation. 
xd = wden(x, 'sqtwolog', hs, 'sln', lev, wname);
res3 = x - xd;
plot(xd) 
axis([0 length(x) 5 15])
title('De-noised signal - Square root')
ylabel('DO [mg/L]')


%% De-noise noisy signal using minimax threshold 
subplot(515)
%  with a multiple level estimation of noise standard deviation. 
xd = wden(x,'minimaxi',hs,'sln',lev,wname);
res4 = x - xd;
plot(xd)
axis([0 length(x) 5 15])
title('De-noised signal - minimaxi');
xlabel('time [h]')
ylabel('DO [mg/L]')

figure(2)
set(2,'Position',[579 52 484 645])
subplot(411)
plot(res1)
axis([0 length(x) -2 2])
title('De-noised signal - Unbiased Risk'); 

subplot(412)
plot(res2)
axis([0 length(x) -2 2])
title('De-noised signal - Heuristic SURE'); 

subplot(413)
plot(res3)
axis([0 length(x) -2 2])
title('De-noised signal - Square root');

subplot(414)
plot(res4)
axis([0 length(x) -2 2])
title('De-noised signal - minimaxi');

% % If many trials are necessary, it is better to perform 
% % decomposition once and threshold it many times:
%  
% % decomposition. 
% [c,l] = wavedec(x,lev,'sym8');
%  
% % threshold the decomposition structure [c,l].
% xd = wden(c,l,'minimaxi','s','sln',lev,'sym8');