% *************************************************************************
%
% Environmental Systems Analysis with Matlab 
% S. Marsili-Libelli
%
%  CRC Press 2016
% ISBN 9781498706353
% Matlab code revised by Emanuele El Basri and Giacomo Barni
% *************************************************************************
% 
% This exercise demonstrates the detrending procedure,
% resulting in a time series with zero mean.
% 
% Sect. 3.3.1.1
%
% *************************************************************************

clear
close all
clc

%% Load the data
load 4_Nov % Flow data from a small WWTP

figure(1)
set(1, 'Position', [15 59 970 482])
% Plot original data
plot(t, q, '.-')
hold on

%% Perform detrending
%  Compute regression line
yp = polyfit(t,q,1);
yt = polyval(yp,t);

%  Subtract regression from the data
ydt=q-yt;
plot(t, ydt, ':r', 'LineWidth',2)
set(gca, 'FontName','Arial', 'FontSize',12)
hold on
plot(t, yt, '--k', 'LineWidth',2)

plot([0 t(end)], [0 0], 'k')
axis([0 24 -250 700])
xlabel('time [h]')
ylabel('Flow [m^3/h]')
set(gca, 'Xtick',[0 6 12 18 24])
legend('Original data', 'Detrended data', 'Trend line',...
           'location','northoutside', 'orientation','horizontal');
