% *************************************************************************
% 
% Environmental Systems Analysis with Matlab 
% S. Marsili-Libelli
%
%  CRC Press 2016
% ISBN 9781498706353
% Matlab code revised by Emanuele El Basri and Giacomo Barni
% *************************************************************************
%
% This exercise demonstrates the smoothing properties of cubic splines.
% The extent of smoothing are assessed by comparing the frequency spectra 
% obtained by the Fast Fourier Transform analysis of the original 
% and smoothed signals.
%
% The indices of the detected outliers are printed in the command window.
%
% Sect. 3.3.3
%
% *************************************************************************

clear
close all

%% Load data
load 4_Nov

figure(1)
clf
set(1, 'Position',[28 442 531 312])
% Plot raw data
plot(t, q, '.-')
hold on

%% Spline smoothing
p = 0.5;
qp = csaps(t, q, p, t);
% Plot smoothed data
plot(t, qp, ':r', 'LineWidth',2)
xlabel('time [h]')
ylabel('Data')
legend('Raw data', 'Smoothed data', 'location','north',...
       'orientation','horizontal');

%% FFT comparison
figure(2)
set(2, 'Position', [577 443 527 311])
% The maximum sampling interval is reduced to 1/6 of the original one
% to obtain a good separation between the hourly and half-hourly
% sampling frequencies.
Fs = Freq_spectrum(t, q, 6*Ts, 2, 1);
t24 = 1/24; % Hourly sampling freq.
t12 = 1/12; % Half-hourly sampling freq.
a = axis;
hold on
semilogy([t24 t24], [a(3) a(4)], ':r')
semilogy([t12 t12], [a(3) a(4)], ':r')
Fs = Freq_spectrum(t, qp, 6*Ts, 2, 2);
legend('Power Spectrum', '24 h', '12 h', 'location','north',...
       'orientation','horizontal')

figure(3)
set(3,'Position',[32 40 525 309])
clf
resid = q - qp;
plot(t, resid)
hold on
plot([0 max(t)], [0 0], ':b')

%% Outliers
ind_out = outlier(resid, 1);
stem(t(ind_out), resid(ind_out), 'r')
xlabel('t [h]')
ylabel('Residuals')
title('Residuals and outliers')
