% *************************************************************************
% 
% Environmental Systems Analysis with Matlab 
% S. Marsili-Libelli
%
%  CRC Press 2016
% ISBN 9781498706353
% Matlab code revised by Emanuele El Basri and Giacomo Barni
% *************************************************************************
%
% This exercise demonstrates the outlier search with percentile delimiting.
% Outliers are detected on the basis of the data rate of change.
%
% Sect. 3.3.2
%
% *************************************************************************

clear
close all
clc

%% Add Tool path
curr_path = pwd; % Get current path
i_rp = strfind(curr_path, 'Exercises'); % Find root level
root_path = curr_path(1:i_rp + 8); % Get root level path
addpath([root_path '/Tools']) % Add Tools path
clear curr_path i_rp root_path

%% Load flow data
load 4_Nov

% Plot the data
figure(1)
clf
set(1,'Position',[33 449 813 303])

subplot(121)
plot(t,q,'.-')
hold on
set(gca, 'FontName','Arial', 'FontSize',10)
set(gca, 'Xtick',[0 6 12 18 24])
xlim([0 24.1])
xlabel('time [h]')
ylabel('Data')

%  Plot the percentiles Q_low and Q_hi
subplot(122)
set(gca, 'FontName','Arial', 'FontSize',10)
[q_out, hq1, hq4] = percentiles(q, 0.1, 0.9)

%% Find the outlying data
figure(1)
subplot(121)
hold on
plot(t(q_out), q(q_out), 'sr', 'MarkerFaceColor','r', 'MarkerSize',3')
set(gca, 'Xtick',[0 6 12 18 24])

%% Outliers detected on the basis of rate of change

%  Differentiale the series
dq = diff(q);
dt = diff(t);
der_q = dq./dt;

figure(2)
clf
set(2, 'Position',[33 51 813 303])
subplot(131)
t1 = t(1:end-1);
plot(t1, der_q, '.-')
set(gca, 'Xtick',[0 6 12 18 24])
xlim([0 24.01])
set(gca, 'FontName','Arial', 'FontSize',10)
xlabel('time [h]')
ylabel('Data rate')

% Plot the percentiles Q_low and Q_hi
subplot(132)
set(gca, 'FontName','Arial', 'FontSize',10)
[q_out, hq1, hq4] = percentiles(der_q, 0.1, 0.9);

subplot(131)
hold on
plot(t1(q_out), der_q(q_out), 'sr', 'MarkerFaceColor','r', 'MarkerSize',3')
axis tight

subplot(133)
q1 = q(1:end-1);
plot(t1, q1, '.-')
set(gca, 'FontName','Arial', 'FontSize',10)
set(gca, 'Xtick',[0 6 12 18 24])
xlim([0 24.1])
xlabel('time [h]')
hold on
plot(t1(q_out), q1(q_out), 'sr', 'MarkerFaceColor','r', 'MarkerSize',3')