% *************************************************************************
% 
% Environmental Systems Analysis with Matlab 
% S. Marsili-Libelli
%
%  CRC Press 2016
% ISBN 9781498706353
% Matlab code revised by Emanuele El Basri and Giacomo Barni
% *************************************************************************
%
% This exercise demonstrates the outlier detection by spline approximation.
% The number of outliers depends on the amount of smoothing.
%
% Sect. 3.3.3
%
% *************************************************************************

clear
close all
clc

%% load data
load 4_Nov
nq = length(q);

%% Spline approximation
p  = 0.95;
qp = csaps(t, q, p, t);

figure(1)
set(gcf, 'Position',[28 45 560 420])
subplot(211)
plot(t,q,'b')
hold on
plot(t,qp,'--r','LineWidth',2)
xlabel('t[h]')
ylabel('y')

subplot(212)
resid = q - qp;
plot(t,resid)
xlabel('t [h]')
ylabel('Residuals')


hold on
plot([0 max(t)],[0 0],':k')

%% Outliers
ind_out = outlier(resid, 1);
stem(t(ind_out), resid(ind_out), 'r')

figure(2)
set(gcf, 'Position',[607 45 560 420])
[bin, Freq, cum_p, p_norm, R_m, R_std] = istg(resid, 25);
legend('Histogram','Gaussian approx.')
hold on
a = axis;
plot([-1.96*R_std 1.96*R_std], [0.95*a(4) 0.95*a(4)], ':r')
plot([-1.96*R_std -1.96*R_std], [a(3) a(4)], ':r')
plot([1.96*R_std 1.96*R_std], [a(3) a(4)], ':r')