% *************************************************************************
% 
% Environmental Systems Analysis with Matlab 
% S. Marsili-Libelli
%
%  CRC Press 2016
% ISBN 9781498706353
% Matlab code revised by Emanuele El Basri and Giacomo Barni
% *************************************************************************
%
% This exercise demonstrates the smoothing properties of cubic 
% approximating splines.
% The effect of varying the smoothing parameter p is considered:
% Several smoothings are performed with decreasing p and its effect is 
% assessed on the basis of the frequency spectrum.
%
% Sect. 3.3.3
%
% *************************************************************************

clear
close all
clc
%% Load the data
load flow 
plotlog = 2; % Semilog plot selected
% set smoothing parameter values
pp=[0.5 0.05 0.005];
figure(1)
set(1, 'Position', [12 57 820 450])
% Plotothiginal data (no smoothing)
[Y, f] = Freq_Analysis(t, q, 1, plotlog);
hold on
a = axis;
t24 = 1/24;
t12 = 1/12;
plot([t24 t24], [a(3) a(4)], ':r')
if max(f) > t12,
   plot([t12 t12], [a(3) a(4)], ':r')
   legend('Power spectrum', '24 h period', '12 h period')
end
set(gca, 'Xtick',[0 6 12 18 24])
subplot(121)
ylabel('Flow [m^3/h]')

% Plot smoothed data
for i=1:3
    p=pp(i);
 pause
 clf
qp = csaps(t, q, p, t); % Data smoothing
[Y, f] = Freq_Analysis(t, qp, 1, plotlog);
hold on
a = axis;
t24 = 1/24;
t12 = 1/12;
plot([t24 t24], [a(3) a(4)], ':r')
if max(f) > t12,
   plot([t12 t12], [a(3) a(4)], ':r')
   legend('Power spectrum', '24 h period', '12 h period')
end
set(gca, 'Xtick',[0 6 12 18 24])
subplot(121)
ylabel('Flow [m^3/h]')
title(['Smoothed data with p = ',num2str(p)])
end
