% *************************************************************************
% 
% Environmental Systems Analysis with Matlab 
% S. Marsili-Libelli
%
%  CRC Press 2016
% ISBN 9781498706353
% Matlab code revised by Emanuele El Basri and Giacomo Barni
% *************************************************************************
%
% This exercise demonstrates the smoothing properties of cubic approximating
% splines and the detection of outliers on a statistical basis.
% A sample located outside the 10th-90th percentile bracket is considered 
% an outliers
%
% Sect. 3.3.3.2
%
% *************************************************************************

clear
close all
clc

%% Load data
load 4_Nov

%plotlog = 2;

figure(1)
set(1, 'Position', [14 77 981 635])
%  Splines
p  = 0.99;
qp = csaps(t,q,p,t);

subplot(2, 2, [1 2])
plot(t,q,'b', t,qp,'--r', 'LineWidth',2)
set(gca, 'Xtick',[0 6 12 18 24])
set(gca, 'FontName','Arial', 'FontSize',12)
xlim([0 24.05])
xlabel('time [h]')
ylabel('Flow [m^3/h]')
legend('Original data', 'Smoothed data', 'location','north',...
       'orientation','horizontal')

subplot(223)
set(gca, 'FontName','Arial', 'FontSize',12)
resid = q - qp;
plot(t, resid)
hold on
plot([0 24], [0 0], 'k')
set(gca, 'Xtick',[0 6 12 18 24])
xlim([0 24.05])
set(gca, 'FontName','Arial', 'FontSize',12)
xlabel('time [h]')
ylabel('Residuals [m^3/h]')

subplot(224)
set(gca, 'FontName','Arial', 'FontSize',12)
[q_out, hq1, hq4] = percentiles(resid, 0.1, 0.9);

subplot(223)
hold on
plot(t(q_out), resid(q_out), 'sr', 'MarkerFaceColor','r', 'MarkerSize',3')
set(gca, 'FontName','Arial', 'FontSize',12)
legend('Residuals', 'Outliers', 'location','north',...
       'orientation','horizontal')