% *************************************************************************
% 
% Environmental Systems Analysis with Matlab 
% S. Marsili-Libelli
%
%  CRC Press 2016
% ISBN 9781498706353
% Matlab code revised by Emanuele El Basri and Giacomo Barni
% *************************************************************************
%
% Reconstruction of missing data using smoothing splines.
% Some data were removed from the data file and they are reconstructed by 
% a cubic approximating spline.
%
% Sect. 3.3.3.1
% 
% *************************************************************************

clear
close all
clc

%% load data
load 4nov     % Full data file
q1 = q;
load 4nov_miss % Missing data file (for comparison)

nq = length(q1);
td = 24*(0:1/nq:1-1/nq);
td = [td 24];
q  = [q', 220];
q1 = [q1', 220];
nq = length(q1);
t = 1:nq;
t = t';
I_miss = isnan(q);
ind = find(I_miss == 1);

%% Spline approximation
figure(1)
set(1, 'Position', [12 36 850 450])
p = 0.9;
qp1 = csaps(t, q1, p, t);
qp2 = csaps(t, q, p, t);
plot(td, q, 'ob', 'MarkerFaceColor','b', 'MarkerSize',5)
hold on
plot(td(ind), q1(ind), 'sb', 'MarkerFaceColor','w', 'MarkerSize',9)
legend('Available data', 'Missing data',...
       'location','northoutside', 'orientation','horizontal')
axis tight
set(gca, 'Xtick',[0 6 12 18 24])
set(gca, 'FontName','Arial', 'Fontsize',12)
xlabel('time [h]')
ylabel('Flow [m^3/h]')
a = axis;
xt = a(1) + 0.025*(a(2) - a(1));
yt = a(3) + 0.9*(a(4) - a(3));
tt=text(xt, yt, 'PAUSED, press any key to continue...',...
                'FontName','Arial', 'Fontsize',12);
pause
delete(tt);
plot(td(ind), qp1(ind), 'sb', 'MarkerFaceColor','b', 'MarkerSize',9)
qq = q;
qq(ind) = qp1(ind);
plot(td, qq, ':k')
legend('Available data', 'Missing data', 'Reconstructed data',...
       'Time series reconstr.',...
       'location','northoutside', 'orientation','horizontal')

text(xt, yt, ['p = ', num2str(p)], 'FontName','Arial', 'Fontsize',12)
set(gca, 'FontName','Arial', 'Fontsize',12)