% *************************************************************************
% 
% Environmental Systems Analysis with Matlab 
% S. Marsili-Libelli
%
%  CRC Press 2016
% ISBN 9781498706353
% Matlab code revised by Emanuele El Basri and Giacomo Barni
% *************************************************************************
%
% This exercise demonstrates the ANFIS capability of approximating a 
% functional relation
%                  y = sqrt(1+(sin(2*x)/exp(x/5)))
% by a set of Sugeno rules.
%
% Sect. 4.4.3.2
%
% *************************************************************************

clear
close all
clc

x = (0:0.05:15)';
y = sqrt(1+(sin(2*x)./exp(x/5))); % Function to be approximated by ANFIS

%% Define ANFIS details
trnData = [x y];
numMFs = 7;
mfType = 'gaussmf';
epoch_n = 55;

%% Generate the initial partition
in_fis = genfis1(trnData, numMFs, mfType);

%% Train the ANFIS
out_fis = anfis(trnData, in_fis, epoch_n);

%% Figures
figure(1)
set(1, 'Position',[29 59 558 404])
plotmf(in_fis, 'input',1)
hold on
plotmf(out_fis, 'input',1)

figure(2) % Display the ANFIS results
set(2, 'Position',[601 58 549 405])
plot(x, y, 'b', 'LineWidth',2)
hold on
plot(x, evalfis(x,out_fis), ':r', 'LineWidth',2);
set(gca, 'FontName','Arial', 'FontSize',12)
title(['Numero mf = ', num2str(numMFs)])
legend('Function', 'ANFIS Approx.');