% *************************************************************************
% 
% Environmental Systems Analysis with Matlab 
% S. Marsili-Libelli
%
%  CRC Press 2016
% ISBN 9781498706353
% Matlab code revised by Emanuele El Basri and Giacomo Barni
% *************************************************************************
%
% This exercise demonstrates the ANFIS capability of approximating a 
% point-wise defined data relation y=f(x) by a set of Sugeno rules.
% In this sense it repeates the Exercise of Sect. 4.3.3 where empirical 
% calibration was attempted.
%
% Sect. 4.4.3.b
%
% *************************************************************************

clear
close all
clc

%% Load the data representing the function
load Fun_up_down

%% Assign the data to x and y vectors
x = Mis_exp(:,1);
y = Mis_exp(:,2);

%% Build the training data set
trnData = [x y];

%% Define the number and type of mfs
numMFs = 5; 
mfType = 'gbellmf';

%% Set the number of training iterations
epoch_n = 20;

%% Generate the initial FIS
in_fis = genfis1(trnData, numMFs, mfType);

%% Train the ANFIS with the data
out_fis = anfis(trnData, in_fis, epoch_n);

%% Figures
figure(1) % Compare the results with the data
set(1, 'Position',[601 58 549 405])
plot(x, y, 'o', 'MarkerSize',6, 'MarkerFaceColor','b')
hold on
plot(x, evalfis(x,out_fis),':r', 'LineWidth',2);
axis([0 10 0.2 2.2])
set(gca, 'FontName','Arial', 'FontSize',14)
legend('Training Data', 'ANFIS Output');
xlabel('x')
ylabel('y')
title(['ANFIS function approximation with ', num2str(numMFs), ' mfs'])

figure(2)
set(2, 'Position',[29 59 558 404])
plotmf(in_fis, 'input', 1)
hold on
plotmf(out_fis, 'input',1)
title('input mfs')