% *************************************************************************
%
% Environmental Systems Analysis with Matlab
% S. Marsili-Libelli
%
%  CRC Press 2016
% ISBN 9781498706353
% Matlab code revised by Emanuele El Basri and Giacomo Barni
% *************************************************************************
%
% Demonstration of the exclusion principle of two competing populations.
%
% Sect. 5.4
%
% *************************************************************************

clear
close all
clc

r1   = 0.4;
r2   = 0.2;
g11  = 0.01;
g22  = 0.02;
g12  = r1*g22/r2+0.02;
g21  = r2*g11/r1+0.005;
tfin = 100;

% Extreme isocline points
% Species 1
K1 = r1/g11;
P1 = r1/g12;
% Species 2
K2 = r2/g22;
P2 = r2/g21;

G = [g11 g12;
    g21 g22];
R = [r1 r2]';
Xo  = G\R
Xo1 = (r1-g12*r2/g22)/(g11-g12*g21/g22)
Xo2 = (r2-g21*r1/g11)/(g22-g21*g12/g11)
J   = [r1-2*g11*Xo(1)-g12*Xo(2),               -g12*Xo(1);
    -g21*Xo(2), r2-g21*Xo(1)-2*g22*Xo(2)];
L = eig(J)

%% Figure
figure(1)
set(1, 'Position',[18 40 560 420])
plot([K1,0], [0,P1], 'b')  % Isocline species 1
set(gca,'FontName','Arial','FontSize',12)
hold on
plot([P2,0], [0,K2], ':r') % Isocline species 2
TTL=title('Right-click to exit');
legend('Species 1', 'Species 2', 'location','north',...
    'orientation','horizontal')
xlabel('x_1')
ylabel('x_2')
% Lables
text('interpreter','latex','position',[1, 1.5], 'fontsize',13,...
     'string','$$\dot{x}_1 > 0$$')
text('interpreter','latex','position',[1, 0.5], 'fontsize',13,...
     'string','$$\dot{x}_2 > 0$$')
text('interpreter','latex','position',[25, 1.5], 'fontsize',13,...
     'string','$$\dot{x}_1 > 0$$')
text('interpreter','latex','position',[25, 0.5], 'fontsize',13,...
     'string','$$\dot{x}_2 < 0$$')
text('interpreter','latex','position',[35, 8.5], 'fontsize',13,...
     'string','$$\dot{x}_1 < 0$$')
text('interpreter','latex','position',[35, 7.5], 'fontsize',13,...
     'string','$$\dot{x}_2 < 0$$')
ax = axis;
x1o = 1;

butt = 1;
while butt == 1
    [x1o, x2o, butt] = ginput(1);
    plot(x1o, x2o, 'o')
    [t,x,y] = sim('coexist', tfin); %Simulation
    plot(simout(:,1), simout(:,2))
    drawnow
end
delete(TTL); clear TTL