% *************************************************************************
%
% Environmental Systems Analysis with Matlab
% S. Marsili-Libelli
%
%  CRC Press 2016
% ISBN 9781498706353
% Matlab code revised by Emanuele El Basri and Giacomo Barni
% *************************************************************************
%
% Demonstration of the extinction of species 2 in the competition between
% two populations
%
% Sect. 5.4
%
% *************************************************************************

clear
close all
clc

r1   = 0.2;
r2   = 0.15;
K1   = 20;
K2   = 25;
x1o  = 5;
x2o  = 10;
tfin = 300;

% Extreme isocline points
g12 = r1/(1.2*K2);
g21 = r2/(0.7*K1);
g11 = r1/K1;
g22 = r2/K2;
P1  = r1/g12;
P2  = r2/g21;

G = [g11 g12;g21 g22];
R = [r1 r2]';
Xo = G\R
J = [r1-2*g11*Xo(1)-g12*Xo(2),               -g12*Xo(1);
    -g21*Xo(2), r2-g21*Xo(1)-2*g22*Xo(2)];
L = eig(J)

%% Figure
figure(1)
set(1, 'Position',[18 40 560 420])
plot([K1,0], [0,P1], 'b')  % Isocline species 1
set(gca, 'FontName','Arial', 'FontSize',12)
hold on
plot([P2,0], [0,K2], ':r') % Isocline species 2
legend('Species 1', 'Species 2', 'location','north',...
       'orientation','horizontal')
xlabel('x_1')
ylabel('x_2')
TTL = title('Right-click to exit');
% Lables
text('interpreter','latex','position',[1, 3.5], 'fontsize',13,...
     'string','$$\dot{x}_1 > 0$$')
text('interpreter','latex','position',[1, 1.5], 'fontsize',13,...
     'string','$$\dot{x}_2 > 0$$')
text('interpreter','latex','position',[14, 3.5], 'fontsize',13,...
     'string','$$\dot{x}_1 > 0$$')
text('interpreter','latex','position',[14, 1.5], 'fontsize',13,...
     'string','$$\dot{x}_2 < 0$$')
text('interpreter','latex','position',[17, 27], 'fontsize',13,...
     'string','$$\dot{x}_1 < 0$$')
text('interpreter','latex','position',[17, 25], 'fontsize',13,...
     'string','$$\dot{x}_2 < 0$$')

butt = 1;
while butt == 1
    [x1o, x2o, butt] = ginput(1);
    plot(x1o, x2o, 'o')
    [t, x, y] = sim('coexist', tfin); % Simulation
    plot(simout(:,1), simout(:,2))
    drawnow
end
delete(TTL); clear TTL