% *************************************************************************
% 
% Environmental Systems Analysis with Matlab 
% S. Marsili-Libelli
%
%  CRC Press 2016
% ISBN 9781498706353
% Matlab code revised by Emanuele El Basri and Giacomo Barni
% *************************************************************************
%
% Simulation of a simple Food chain model including Primary Production,
% Herbivores, and Carnivores.
%
% Sect. 5.6
% 
% *************************************************************************

clear
close all
clc

rg  = 0.8721 ; 		 % Grass growth rate                              [1/d]
kg  = 83; 		     % Grass half velocity constant                 [kg/m2]
kdg = 0.23; 		 % Grass decay rate                               [1/d]
Yh  = 0.141; 		 % Grass grazing yield                              [-]
g1  = 0.02224; 		 % Herbivores growth rate                         [1/d]
Pr1 = 668; 			 % Herbivores half velocity constant            [kg/m2]
kd1 = 0.02103;       % Herbivores decay rate                          [1/d]
g2  = 0.00351 ;		 % Carnivores growth rate                         [1/d]
Pr2 = 854; 		     % Carnivores half velocity constant            [kg/m2]
kdc = 0.00122;       % Carnivores decay rate                          [1/d]
Yc  = 0.025; 		 % Carnivores yield constant                        [-]

Base = 30;
Go   = 4500;           % Initial state
Ho   = 460;            % Initial state
Co   = 33;             % Initial state
tend = 720*2;

%% Simulation
[y, x, t] = sim('Food_Chain', [0 tend]);

%% Figures
figure(1)
set(1, 'Position',[18 40 872 420])

subplot(221);
plot(time, Sol_Rad);
title('Solar Radiation');
xlabel('Days')

subplot(222);
plot(time,Grass);
title('Grass');
xlabel('Days')

subplot(223);
plot(time,Herb);
title('Herbivores');
xlabel('Days')

subplot(224);
plot(time,Carn);
title('Carnivores');
xlabel('Days')