% *************************************************************************
% 
% Environmental Systems Analysis with Matlab 
% S. Marsili-Libelli
%
%  CRC Press 2016
% ISBN 9781498706353
% Matlab code revised by Emanuele El Basri and Giacomo Barni
% *************************************************************************
%
% Simulation of a simple Food chain model including Primary Production,
% Herbivores, and Carnivores with experimental solar radiation data and
% adjustable parameters.
%
% Sect. 5.6
% 
% *************************************************************************

clear
close all
clc

%% Data load
load Sol_rad
tend = max(Sol_rad(:,1));
prompt = {'Grass growth rate [1/d]',...
          'Grass half velocity constant [kg/m2]',...
		  'Grass decay rate [1/d]', 'Grass grazing yield [-]',...
          'Herbivores growth rate [1/d]',...
		  'Herbivores half velocity constant [kg/m2]',...
		  'Herbivores decay rate [1/d]', 'Carnivores growth rate [1/d]',...
		  'Carnivores half velocity constant [kg/m2]',...
		  'Carnivores decay rate [1/d]', 'Carnivores yield constant [-]',...
          'Initial grass', 'Initial Herbivores', 'Initial Cornivores'};
def = {'0.8721', '83', '0.23', '0.141', '0.02224', '668', '0.02103',...
       '0.00351', '854', '0.00122', '0.025', '12500', '760', '17'};
data = inputdlg(prompt,'Simulation of a simple Food Chain', 1, def);
data = char(data);

rg  = str2num(data(1,:));		% Grass growth rate                   [1/d]
kg  = str2num(data(2,:));	 	% Grass half velocity constant      [kg/m2]
kdg = str2num(data(3,:));		% Grass decay rate                    [1/d]
Yh  = str2num(data(4,:));		% Grass grazing yield                   [-]
g1  = str2num(data(5,:));		% Herbivores growth rate              [1/d]
Pr1 = str2num(data(6,:));		% Herbivores half velocity constant [kg/m2]
kd1 = str2num(data(7,:));		% Herbivores decay rate               [1/d]
g2  = str2num(data(8,:));		% Carnivores growth rate              [1/d]
Pr2 = str2num(data(9,:));		% Carnivores half velocity constant [kg/m2]
kdc = str2num(data(10,:));	    % Carnivores decay rate               [1/d]
Yc  = str2num(data(11,:));		% Carnivores yield constant             [-]

Go = str2num(data(12,:));		% Grass initial condition
Ho = str2num(data(13,:));		% Herbivore initial condition
Co = str2num(data(14,:));		% Carnivore initial condition

%% Simulation
[y, x, t] = sim('Food_Chain_Data', [0 tend]);

%% Figures
figure(1)
set(1, 'Position',[18 40 872 420])

subplot(221);
plot(time, Sol_Rad, 'b');
title('Solar Radiation');
xlabel('Days')

subplot(222);
plot(time, Grass, 'b');
title('Grass');
xlabel('Days')

subplot(223);
plot(time, Herb, 'b');
title('Herbivores');
xlabel('Days')

subplot(224);
plot(time, Carn, 'b');
title('Carnivores');
xlabel('Days')