% *************************************************************************
%
% Environmental Systems Analysis with Matlab
% S. Marsili-Libelli
%
%  CRC Press 2016
% ISBN 9781498706353
% Matlab code revised by Emanuele El Basri and Giacomo Barni
% *************************************************************************
%
% Demonstration of the proportional harvesting of a critically depensated 
% populations (zero initial derivative of the growth curve..
%
% Sect. 5.3.2.1
%
% *************************************************************************

clear
close all
clc

K = 10;
r = 0.12;
i = 0;
dtoll = 0.1
x = 0:K/20:K;
F = r*(1-x./K).*x.^3;

%% Figures
figure(1)
set(1, 'Position',[18 40 560 420])
set(gca, 'FontName','Arial', 'FontSize',12)
plot(x, F, 'b')
axis(axis)
hold on
for g = 0:0.07:2;
    i = i + 1;
    G(i) = g;
    H=g*x;
    figure(1)
    hold on
    plot(x,H,':r')
    Fpol=[1 -K  0 g*K/r];
    X=roots(Fpol);
    if max(abs(imag(X))) > dtoll
        break
    end
    x1(i) = X(1);
    x2(i) = X(2);
    H1(i) = g*x1(i);
    H2(i) = g*x2(i);
    plot(x1(i), g*x1(i), 'ob','MarkerFaceColor','b')
    hold on
    plot(x2(i), g*x2(i), 'or','MarkerFaceColor','r')
end
xlabel('Population')
ylabel('F(x)')
legend('Rate', 'Harvest', 'Stable', 'Unstable',...
    'location','northoutside', 'orientation','horizontal')

figure(2) % Yield curve plotting extreme tangent point
set(2, 'Position',[598 39 560 420])
set(gca, 'FontName','Arial', 'FontSize',12)
sh = size(H1);
plot(G(1:sh(2)),H1,'ob','MarkerFaceColor','b')
hold on
plot(G(1:sh(2)),H2,'or','MarkerFaceColor','r')
hold on
plot(G(1:sh(2)), H1, 'b')
plot(G(1:sh(2)), H2, 'r')
xlabel('g')
ylabel('Y')
legend('Stable branch','Unstable branch','location','northoutside','orientation','horizontal')