% *************************************************************************
%
% Environmental Systems Analysis with Matlab
% S. Marsili-Libelli
%
%  CRC Press 2016
% ISBN 9781498706353
% Matlab code revised by Emanuele El Basri and Giacomo Barni
% *************************************************************************
%
% Demonstration of the proportional harvesting of a simply depensated and 
% critically depensated populations.
%
% Sect. 5.3.2.1
%
% *************************************************************************

clear
close all
clc

K = 10;
i = 0;
x = 0:0.2:10;
p = [-0.0015   -0.0049    0.1664    0.2967    0.0056];
f = polyval(p, x);

%% Figures
figure(1)
set(1, 'Position',[18 40 560 420])
set(gca, 'FontName','Arial', 'FontSize',12)
Plot.growth=plot(x, f, 'b','LineWidth',2);
axis([0 K 0 5.5])
hold on
axis(axis)
xlabel('X')
ylabel('dX/dt')
pp = p;
x1 = [];
x2 = [];
incr = 0.06;
Radici = 0;
g = 0;
while Radici == 0
    i = i+1;
    G(i) = g;
    H = g*x;
    figure(1)
    hold on
    Plot.curve=plot(x, H,':r');
    pp(4) = p(4) - g;
    X = roots(pp);
    Re = find((imag(X) == 0) & (real(X) > 0.1));
    Radici = isempty(Re);
    Xr = X(Re);
    Xr = sort(Xr);
    sX = size(Xr);
    if sX(1) == 1
        x2(i) = Xr(1);
        H2(i) = g*x2(i);
        % Stable points
        Plot.stable=plot(x2(i), g*x2(i), 'ob','MarkerFaceColor','b');
    end
    if sX(1) == 2
        x1(i) = Xr(1);
        x2(i) = Xr(2);
        H1(i) = g*x1(i);
        H2(i) = g*x2(i);
        % Unstable points
        Plot.Unstable=plot(x1(i), H1(i), 'or','MarkerFaceColor','r') ;
        hold on
        % Metastable points
        Plot.meta=plot(x2(i), H2(i), 'oc','MarkerFaceColor','c');
    end
    g = g + incr;
    incr = incr/1.067;
end
legend([Plot.growth,Plot.curve,Plot.stable,Plot.Unstable,Plot.meta],...
    'Growth curve','Harvest line','Stable points',...
    'Unstable points','Metastable points',...
    'location','northwest')
figure(2) % Yield curve plotting extreme tangent point
set(2, 'Position',[598 39 560 420])
set(gca, 'FontName','Arial', 'FontSize',12)
sh = size(H2);
G = G(1:sh(2));
h2_last = H2(end);
h1_last = H1(end);
h_last = h1_last + (h2_last - h1_last)/2;
H2 = [H2 h_last];
H1 = [H1 h_last];
G = [G G(length(G))];
plot(G, H2, 'b','LineWidth',2)
hold on
axis(axis)
gg = G([max(find(H1 == 0)), find(H1 > 0)]);
h3 = H1([max(find(H1 == 0)), find(H1 > 0)]);
plot(gg, h3, '--r','LineWidth',2)
xlabel('g')
ylabel('Y')
legend('Stable branch', 'Unstable branch', 'location','northoutside',...
       'orientation','horizontal')