% *************************************************************************
%
% Environmental Systems Analysis with Matlab
% S. Marsili-Libelli
%
%  CRC Press 2016
% ISBN 9781498706353
% Matlab code revised by Emanuele El Basri and Giacomo Barni
% *************************************************************************
%
% Demonstration of the Leslie age class model applied to Poa annua weed
% The seed production and survival rates were obtained from 
% Begon and Mortimer, (1986).
%
% Sect. 5.2.2.3
%
% *************************************************************************

clear
close all
clc
%% ------------------------------------------------------------------------
Nclass = 5;
Xold = [800 200 100 50 10]';

Tmax = 30;
Xnew=zeros(Nclass,Tmax+1);
Xnew(:,1)=Xold;

%% Figures
figure(1)
set(1, 'Position',[18 40 560 420])
set(gca, 'FontName','Arial', 'FontSize',12)
XX = [];
XX(1,:) = Xold;
for i = 2:Tmax+1;
    N = sum(Xold); % Coefficients computation
    po = max(0, 0.75-0.25*exp(0.00005*N));
    B1 = 100*exp(-0.0001*N);
    B3 = B1;
    B2 = 2*B1;
    A = [0.2,  0,   B1,    B2,    B3 ;  % Leslie matrix
         0.05, 0,   0,     0,      0 ;
         0,    po,  0,     0,      0 ;
         0,    0,   0.75,  0,      0 ;
         0,    0,   0,     0.75,   0];
    
    %% Model simulation
    Xnew = A*Xold;
    XX = [XX; Xnew'];
    Xold = Xnew;
    autoval = eig(A); % Eigenvalue computation
    for j=1:5
        plot(real(autoval(j)), imag(autoval(j)), 'or')
        hold on
    end
end;
a = axis;
unit_circle(1.5,1.5)
plot([a(1) a(2)], [0 0], 'k')
plot([0 0], [a(3) a(4)], 'k')
title('Poa annua model eigenvalues')
t = 0:Tmax; % Display population evolution

figure(2)
set(2, 'Position',[598 39 560 420])
set(gca, 'FontName','Arial', 'FontSize',12)
XX = fliplr(XX);
bar3(t, log(XX))
axis equal
colormap spring
ylabel('time [yr]')
xlabel('Age class')
zlabel('log(pop)')
title('Evolution of Poa annua age population')