% *************************************************************************
%
% Environmental Systems Analysis with Matlab
% S. Marsili-Libelli
%
%  CRC Press 2016
% ISBN 9781498706353
% Matlab code revised by Emanuele El Basri and Giacomo Barni
% *************************************************************************
%
% Demonstration of the Logistic growth model.
%
% Sect. 5.1.2
%
% *************************************************************************

clear
close all
clc

r    = 0.4;  % Model parameters
K    = 10;   % Carrying capacity
tend = 30;   % Final simulation time
x0   = 0.5;  % Initial population

%% Growth rate plotting
figure(1) 
set(1, 'Position',[38 82 422 423])
x = 0:K/20:K;
dx = r*x.*(1-x./K);
plot(x, dx,'LineWidth',2)
xlabel('X')
title('x\cdotF(x)')
hold on
a = axis;
plot([K/2 K/2], [a(3) a(4)], ':k')

%% Simulation with a varying r
figure(2)
set(2,'Position',[476 84 560 420])
for r = 0.2:0.2:0.6
    [t, x, y] = sim('Logistic', tend);
    plot(t,x,'b',t,x1*10,':r','LineWidth',2)
    drawnow
    hold on
    xmax  = find(x1 == max(x1));
    plot([t(xmax) t(xmax)], [0 10*max(x1)], ':k')
    drawnow
end
xlabel('time')
ylabel('X, dX/dt')
title('Logistic growth model with a varying r')
legend('Population', 'Derivative','Maximum derivative')