% *************************************************************************
%
% Environmental Systems Analysis with Matlab
% S. Marsili-Libelli
%
%  CRC Press 2016
% ISBN 9781498706353
% Matlab code revised by Emanuele El Basri and Giacomo Barni
% *************************************************************************
%
% Demonstration of the effect of a varying r or n
% in the Richards growth model.
%
% Sect. 5.1.4
%
% *************************************************************************

clear
close all
clc

xo   = 0.01; % Initial population
K    = 10;   % Carrying capacity
n    = 1.2;  % Growth exponent
tend = 50;   % Simulation time
r=0.6;       % Growth rate

%% Figures
figure(1)
set(1,'Position',[38 50 600 400])
for r = 0.3:0.3:1.2
    [t,x,y] = sim('Richards', tend); % Simulation
    plot(t, x, t, 10*rate, '--b')
    hold on
    ir = find(rate == max(rate));
    xmax = x(ir);
    tmax = t(ir);
    plot(tmax, xmax, 'or','MarkerFaceColor','r')
    drawnow
end
set(gca, 'FontName','Arial', 'FontSize',12)
xlabel('time')
ylabel('Population')
legend('x','10*dx/dt','Inflexion point')
title('Richards model with a varying growth rate r')

%% Effect of a varying exponent n
% reste the growth rate initial value
r=0.6;       % Growth rate

figure(2)
set(2,'Position',[656 50 600 400])
for n = 1:0.5:3
    [t,x,y] = sim('Richards', tend); % Simulation
    plot(t, x, t, 10*rate, '--b')
    hold on
    ir = find(rate == max(rate));
    xmax = x(ir);
    tmax = t(ir);
    plot(tmax, xmax, 'or','MarkerFaceColor','r')
    drawnow
end
set(gca, 'FontName','Arial', 'FontSize',12)
xlabel('time')
ylabel('Population')
legend('x','10*dx/dt','Inflexion point')
title('Richards model with a varying exponent n')