% *************************************************************************
%
% Environmental Systems Analysis with Matlab
% S. Marsili-Libelli
%
%  CRC Press 2016
% ISBN 9781498706353
% Matlab code revised by Emanuele El Basri and Giacomo Barni
% *************************************************************************
%
% Root locus of the Logistic equation with delay.
%
% Sect. 5.1.2.1
%
% *************************************************************************

clear
close all
clc

r = 0.7; % Growth rate
R = [];
delta = [0.5, 0.55, 0.591733661, 0.592:0.005:0.7, 0.7:0.01:1.43,...
         1.43:0.1:30]; % Critical locus branches
n = length(delta);
for i = 1:n
    d = delta(i);
    coeff_eq = [1 2.*(1-r*d)/(r*d^2) 2./(d^2)];
    rr = roots(coeff_eq);
    R = [R rr];
end
RR = real(R);
RI = imag(R);

%% Figure
figure(1)
set(1, 'Position',[21 61 771 500])
set(gca, 'FontName','Arial', 'FontSize',12)
plot(RR(1,:), RI(1,:))
hold on
plot(RR(2,:), RI(2,:))
axis([-4 0.5 -1.5 1.5])
axis(axis)
axis equal
a = axis;
plot([0 0], [a(3) a(4)], 'k')
plot([a(1) a(2)], [0 0], 'k')
xlabel('Real axis')
ylabel('Imaginary axis')