% *************************************************************************
% 
% Environmental Systems Analysis with Matlab 
% S. Marsili-Libelli
%
%  CRC Press 2016
% ISBN 9781498706353
% Matlab code revised by Emanuele El Basri and Giacomo Barni
% *************************************************************************
%
% Comparison of single-species continuous-time population models. 
%
% Sect. 5.1
%  
% *************************************************************************

clear
close all
clc

xo   = 0.01;   % Initial population
K    = 5;      % Common Carrying capacity
nr   = 1.5;    % Richards exponent
nb   = 0.667;  % Bertlanffy exponent
kd   = 0.6436; % Bertlanffy decay rate
r    = 0.5;    % Logistic growth rate
rg   = 0.35;   % Gompertez growth rate
rr   = 0.5;    % Richards growth rate
rb   = 1.1;    % Bertlanffy growth rate
tend = 30;     % Simulation horizon

%% Simulate models
[t, x, y] = sim('Growth_Models', tend);

%% Figure
figure(1)
set(1, 'Position',[31 39 947 476])
subplot(121)
plot(t,x_L,'b', t,x_G,':b', t,x_R,'--b', t,x_B,'-.b')
set(gca, 'FontName','Arial', 'FontSize',12)
xlabel('time')
ylabel('Population')
legend('Logistic', 'Gompertez', 'Richards', 'Bertlanffy',...
       'location','southeast', 'orientation','vertical')
subplot(122)
plot(x_L,rate_L,'b', x_G,rate_G,':b', x_R,rate_R,'--b', x_B,rate_B,'-.b')
set(gca, 'FontName','Arial', 'FontSize',12)
xlabel('Population')
ylabel('Growth rate')