% *************************************************************************
%
% Environmental Systems Analysis with Matlab
% S. Marsili-Libelli
%
%  CRC Press 2016
% ISBN 9781498706353
% Matlab code revised by Emanuele El Basri and Giacomo Barni
% *************************************************************************
%
% Demonstration of the Feigenbaum bifurcation diagram for the 
% discrete-time Logistic equation showing the period-doubling phenomenon.
%
% Sect. 5.2.1.1
%
% *************************************************************************

clear
close all
clc

r = 2.76;
K = 25;
a = 1 + r;
b = r/K;

%% Figures
figure(1)
set(1, 'Position',[18 40 560 420])
set(gca, 'FontName','Arial', 'FontSize',12)
axis([2.5 4 0 1])
set(gca, 'FontName','Arial', 'FontSize',16, 'Box','off')
xlabel('\alpha')
ylabel('x')
hold on
for alpha = 2.5:0.005:3.99
    z(1) = 0.5;
    for i = 2:200
        z(i) = alpha*z(i-1)*(1-z(i-1));
    end
    figure(1)
    plot(alpha, z(170:199), '.b')
    hold on
    drawnow
    figure(2)
    set(2, 'Position',[598 39 560 420])
    set(gca, 'FontName','Arial', 'FontSize',12)
    plot(z(180:200), 'o-b')
    axis([0 20 0 1])
    ylabel('x')
    drawnow
end
figure(2)
xlabel('time')
ylabel('Population')