% *************************************************************************
%
% Environmental Systems Analysis with Matlab
% S. Marsili-Libelli
%
%  CRC Press 2016
% ISBN 9781498706353
% Matlab code revised by Emanuele El Basri and Giacomo Barni
% *************************************************************************
%
% Demonstration of the Feigenbaum bifurcation diagram for the Logistic
% equation showing the period-doubling phenomenon.
%
% Sect. 5.2.1.1
%
% *************************************************************************

clear
close all
clc

rmin = 5;
K = 2;

%% Figures
figure(1)
set(1, 'Position',[18 40 560 420])
set(gca, 'FontName','Arial', 'FontSize',12)
for r = rmin:0.05:20
    z(1) = 0.5;
    for i = 2:200
        Rr = r.^(1-z(i-1)/K);
        z(i) = Rr.*z(i-1);
    end
    figure(1)
    plot(r, z(170:199), '.b')
    axis([5 20 0 5])
    axis(axis)
    xlabel('R_{max}')
    ylabel('z')
    hold on
    drawnow
    figure(2)
    set(2, 'Position',[598 39 560 420])
    set(gca, 'FontName','Arial', 'FontSize',12)
    plot(z(180:200), '-ob')
    drawnow
end
figure(2)
xlabel('time')
ylabel('Population')