% *************************************************************************
%
% Environmental Systems Analysis with Matlab
% S. Marsili-Libelli
%
%  CRC Press 2016
% ISBN 9781498706353
% Matlab code revised by Emanuele El Basri and Giacomo Barni
% *************************************************************************
%
% Simulation of the Spruce budworm model.
% Ludwig et al., 1978
%
% Sect. 5.5.3.2 
%
% *************************************************************************

clear
close all
clc

r = 0.84;
Q = 8;

%% Search for equilibria
for r = 0.25:0.1:0.95;
    xx = 0:0.05:8;
    f = r*(1-xx./Q);
    g = xx./(1+xx.^2);
    
    
    %% Simulation
    tend = 100; % Time simulation
    xo = 3.5;
    [t, x, y] = sim('sb', tend);
    
    fe = r*(1-x(end)/Q);
    ge = xx./(1+x(end)^2);
    
    %% Figures
    figure(1)
    set(1, 'Position',[18 40 560 420])
    subplot(211)
    plot(xx,f,':b', xx,g,'b')
    set(gca, 'FontName','Arial', 'FontSize',12)
    ylabel('f(x), g(x)')
    TTL = title('Press the space bar to increase R');
    hold on
    ax=axis;
    plot([ax(1) ax(2)], [0 0], 'k')
    plot(x(end), fe, 'ob','MarkerFaceColor','b')
    legend('Logistic', 'Type 2 funct. resp.', 'Equilibrium')
    
    subplot(212)
    plot(x, dx, 'r')
    set(gca,'FontName','Arial', 'FontSize',12)
    hold on
    plot(x(end), 0, 'or','MarkerFaceColor','r')
    axis([0 8 -0.5 1])
    plot([0 8], [0 0], 'k')
    xlabel('Spruce budworm density')
    ylabel('dx/dt')
    
    figure(2)
    set(2, 'Position',[598 39 560 420])
    plot(t, x)
    hold on
    axis([0 tend 0 8])
    set(gca, 'FontName','Arial', 'FontSize',12)
    xlabel('time')
    ylabel('Spruce budworm density')
    
    pause
end
delete(TTL); clear TTL