% *************************************************************************
% 
% Environmental Systems Analysis with Matlab 
% S. Marsili-Libelli
%
%  CRC Press 2016
% ISBN 9781498706353
% Matlab code revised by Emanuele El Basri and Giacomo Barni
% *************************************************************************
%
% Simulation of a CSTR with a square wave input flow.
%
%
% Sect. 6.1.1.2
% 
% *************************************************************************

clear
close all
clc

%% Set parameters
V               = 10;  % Vol of the tank
F               = 7.5; % Process flow
Ci              = 5;   % Input concentration
k               = 0.3; % First order kinetic
Tp              = 0.05;
Ap              = 4;
Noise_mean      = 0;
Noise_variance  = 0.2;
Tmax            = 50;

prompt = {'Vol. of the tank', 'Process flow', 'Input concentration',...
          'First order kinetics', 'Input square wave period',...
          'Amplitude', 'Noise mean', 'Noise variance', 'Simulation length'};
def = {'10', '7.5', '5', '0.3', '0.05', '4', '0', '0.2', '50'};
data = inputdlg(prompt, '1st order CSTR', 1, def);
data = char(data);
V              = str2num(data(1,:));
F              = str2num(data(2,:));
Ci             = str2num(data(3,:));
k              = str2num(data(4,:));
Tp             = str2num(data(5,:));
Ap             = str2num(data(6,:));
Noise_mean     = str2num(data(7,:));
Noise_variance = str2num(data(8,:));
Tmax           = str2num(data(9,:));

q = F/V; % Initial dilution
Co = Ci*q/(q+k); % Initial output concentration
[y,x,t] = sim('CSTR_square', Tmax);

%% Figure
figure(1)
set(1, 'Position',[18 40 560 420])
hold off
clf
subplot(211)
set(gca,'FontName','Arial','FontSize',11)
plot(t_sim, flow/5)
ylabel('Flow/5 (m^3/s)')
xlabel('time')
subplot(212)
set(gca,'FontName','Arial','FontSize',11)
plot(t_sim, conc)
ylabel('Concentration')
xlabel('time')