% *************************************************************************
% 
% Environmental Systems Analysis with Matlab 
% S. Marsili-Libelli
%
%  CRC Press 2016
% ISBN 9781498706353
% Matlab code revised by Emanuele El Basri and Giacomo Barni
% *************************************************************************
%
% Simulation of the input response of an inert tracer.
%
%
% Sect. 6.1.2
%
% *************************************************************************

clear
close all

%% Load params
load Dif_11
Cexp = xd(:,2);
texp = xd(:,1);
I_lag = 8;
t_lag = texp(I_lag);

%% Find the peak concentration
Icm = find(Cexp == max(Cexp));
Cmax = Cexp(Icm);
tmax = texp(Icm) - t_lag;

%% Build time base
%  Elapsed time [s]
t = linspace(texp(I_lag)-texp(I_lag), texp(end)-texp(I_lag),100);

n = 3;
Nn = factorial(n-1);
q = (n-1)/tmax;% Dilution rate
theta = 1/q;
Co = 1.38;
C  = Co*(q^(n-1)/Nn)*(t.^(n-1)).*exp(-t*q);

%% Figure
figure(1)
set(gca, 'FontName','Arial', 'FontSize',12)
plot(xd(:,1),xd(:,2),'ob','MarkerFaceColor','b')
hold on

plot(t+t_lag, C)
xlabel('time [s]')
ylabel('Conc. [mg/L]')