% *************************************************************************
% 
% Environmental Systems Analysis with Matlab 
% S. Marsili-Libelli
%
%  CRC Press 2016
% ISBN 9781498706353
% Matlab code revised by Emanuele El Basri and Giacomo Barni
% *************************************************************************
%
% Simulation of a cascade of CSTRs with first-order kinetics.
%
%
% Sect. 6.1.2 and Fig. 6.7
% 
% *************************************************************************

clear
close all
clc

%% Set parameters
q    = 0.12;  % Dilution rate [1/h]
k    = 0.001; % Kintetics     [1/h]
tfin = 100;

%% Pulse response
Co = 1; % Initial concentration
Ci = 0; % Input concentration
[tp, xp, yp] = sim('CSTR_cascade', tfin);

%  Figure
figure(1)
set(1, 'Position',[18 40 557 355])
set(gca, 'FontName','Arial', 'FontSize',12)
set(gca, 'LineStyleOrder', {'-', ':', '-.', '.-', '.'})
ls = ['b', 'r', 'k', 'm', 'c'];
for i = 1:5
    plot(tp, C(:,i), ls(i))
    hold on
end
legend('1', '2', '3', '4', '5')
xlabel('time (h)')
ylabel('Conc. [mg/L]')
title('Pulse response')

%% Step response
Co = 0; % Initial concentration
Ci = 1; % Input concentration
[ts, xs, ys] = sim('CSTR_cascade', tfin);

%  Figures
figure(2)
set(2, 'Position',[590 40 557 355])
set(gca, 'FontName','Arial', 'FontSize',12)
for i = 1:5
    plot(ts, C(:,i), ls(i))
    hold on
end
legend('1', '2', '3', '4', '5','location','east')
xlabel('time (h)')
ylabel('Conc. [mg/L]')
title('Step response')