% *************************************************************************
%
% Environmental Systems Analysis with Matlab
% S. Marsili-Libelli
%
%  CRC Press 2016
% ISBN 9781498706353
% Matlab code revised by Emanuele El Basri and Giacomo Barni
% *************************************************************************
%
% Demonstration of the fractionation effect on reactor volumes with first
% order kinetics, compared to the Plug-Flow configuration.
%
% Sect. 6.1.3
%
% *************************************************************************

clear
close all
clc

%% Set figure
figure(1)
set(1,'Position',[23 48 1001 567])
hold off;
clf;

%% Fractionation in 2 reactors
Nda  = 2;
Nmax = 2;
c = 1:Nmax;
v = 0:(1/Nmax):1;
for n = 2:Nmax+1;
    c(n) = c(n-1)/(1+Nda/Nmax);
end
c = [c(2:n) c(n)];

%  Figure
subplot(221);
set(gca,'FontName','Arial','FontSize',11)
stairs(v,c);
hold on
x = 0:0.01:1;
plot(x, exp(-Nda*x), ':r')
xlabel('Normalized volume')
ylabel('Extent of reaction')
title(['Fractionation in ', num2str(Nmax), ' reactors'])
legend('Fractionation','Plug Flow','location','north','orientation','horizontal')
hold off

%% Fractionation in 4 reactors
Nmax = 4;
c = 1:Nmax;
v = 0:(1/Nmax):1;
for n = 2:Nmax+1;
    c(n) = c(n-1)/(1+Nda/Nmax);
end
c = [c(2:n) c(n)];

%  Figure
subplot(222);
set(gca,'FontName','Arial','FontSize',11)
stairs(v, c);
hold on
x = 0:0.01:1;
plot(x, exp(-Nda*x), ':r')
xlabel('Normalized volume')
ylabel('Extent of reaction')
title(['Fractionation in ', num2str(Nmax), ' reactors'])
legend('Fractionation','Plug Flow','location','north','orientation','horizontal')
hold off

%% Fractionation in 6 reactors
Nmax = 6;
c = 1:Nmax;
v = 0:(1/Nmax):1;
for n = 2:Nmax+1;
    c(n) = c(n-1)/(1+Nda/Nmax);
end
c = [c(2:n) c(n)];

%  Figure
subplot(223);
set(gca,'FontName','Arial','FontSize',11)
stairs(v, c);
hold on
x = 0:0.01:1;
plot(x, exp(-Nda*x), ':r')
xlabel('Normalized volume')
ylabel('Extent of reaction')
title(['Fractionation in ', num2str(Nmax), ' reactors'])
legend('Fractionation','Plug Flow','location','north','orientation','horizontal')
hold off

%% Fractionation in 8 reactors
Nmax = 8;
c = 1:Nmax;
v = 0:(1/Nmax):1;
for n = 2:Nmax+1;
    c(n) = c(n-1)/(1+Nda/Nmax);
end
c = [c(2:n) c(n)];

%  Figure
subplot(224);
set(gca,'FontName','Arial','FontSize',11)
stairs(v, c);
hold on
x = 0:0.01:1;
plot(x, exp(-Nda*x), ':r')
xlabel('Normalized volume')
ylabel('Extent of reaction')
title(['Fractionation in ', num2str(Nmax), ' reactors'])
legend('Fractionation','Plug Flow','location','north','orientation','horizontal')
