% *************************************************************************
% 
% Environmental Systems Analysis with Matlab 
% S. Marsili-Libelli
%
%  CRC Press 2016
% ISBN 9781498706353
% Matlab code revised by Emanuele El Basri and Giacomo Barni
% *************************************************************************
%
% Computation of the longitudinal dispersion dynamic 
% using the Fisher equation
%
% Sect. 6.3.3
% 
% *************************************************************************

clear 
close all
clc

uo = 0.015;    % Velocity       [m/s]
w  = 35;       % River width      [m]
s  = 0.00001;  % Slope
h0 = 0.8;      % Mean river depth [m]

u = linspace(0.001, 0.1, 50);
h = linspace(0.5, 1.5, 50);
[U, H] = meshgrid(u, h);
Dif_Fisher = 0.011*U.^2*w^2./(H.*sqrt(9.81*s.*H));

figure(1)
surf(U, H, Dif_Fisher)
xlabel('Velocity [m/s]')
ylabel('River depth [m]')
zlabel('Diffusion')
shading interp
rotate3d on