%**************************************************************************
%
% Environmental Systems Analysis with Matlab 
% S. Marsili-Libelli
%
%  CRC Press 2016
% ISBN 9781498706353
% Matlab code revised by Emanuele El Basri and Giacomo Barni
% *************************************************************************
%
% Diffusive reactor pulse response according to Eq. (6.80)
% 
%
% Sect. 6.3.3.1
%
% *************************************************************************

clear
close all
clc

u = 1.2;  % Velocity
D = 0.2;  % Diffusivity
M = 1;    % Injected mass
S = .3;   % Cross-section
x = linspace(1, 15, 250);
t = linspace(1, 12, 250);
[T X] = meshgrid(t, x);

C=(M./(2*S*sqrt(pi*D.*T))).*exp(-((X-u.*T).^2)./4*D.*T);

%% Figure
figure(1)
set(1,'Position',[20 39 560 420])
% C=flipud(C);
surf(T, X, C)
axis tight
shading interp
view([112 50])
rotate3d on
ylabel('length')
xlabel('time')
zlabel('Conc.')