% *************************************************************************
% 
% Environmental Systems Analysis with Matlab 
% S. Marsili-Libelli
%
%  CRC Press 2016
% ISBN 9781498706353
% Matlab code revised by Emanuele El Basri and Giacomo Barni
% *************************************************************************
%
% Demonstration of the boundary value problem (BVP) of the steady-state 
% diffusive equation.
%
% Sect. 6.3.5.3 
% 
% *************************************************************************

clear
close all
clc

%% Set parameters
global tfin dci Cin Co t C 

u = 0.001;   % Velocity                [m/s]
D = 5000;    % Diffusion coefficient [m^2/s]
L = 100000;  % Length                    [m]
k = 1.40e-6; % Kinetics               [s^-1]


tfin = 1;
dci = -9.3; % Initial condition
Co = 2.5;   % Initial concentration
Cin = 10;   % Initial derivative

% Set figure
figure(1)
set(1,'Position',[18 40 557 355])
set(gca,'FontName','Arial','Fontsize',12)

%% Run simulation
[dC_dz error] = fminsearch('diffu_BV', dci)

plot(t,C)
hold on
%axis([0 1 Co-1 max(C)+1])
axis(axis)
title('BVP solution of the stationary profile')
xlabel('Normalized length')
ylabel('Concentration')
plot([0.9 1], [Co Co], '-.r')
text(0.75, Co, ['C_0 = ', num2str(Co)])

D/(u*L)
x_exp = t([1000 1700 2800 4000 5000]);
Cexp = C([1000 1700 2800 4000 5000]);

save Data_sperim x_exp Cexp