% *************************************************************************
% 
% Environmental Systems Analysis with Matlab 
% S. Marsili-Libelli
%
%  CRC Press 2016
% ISBN 9781498706353
% Matlab code revised by Emanuele El Basri and Giacomo Barni
% *************************************************************************
%
% Demonstration of the Least-Squares boundary conditions for the
% steady-state diffusive equation.
%
% Sect. 6.3.5.c 
% 
% *************************************************************************

clear
close all
clc

%% Set parameters
global tfin u L D Cin dci Co Cout t C k Cexp x_exp

load Data_sperim

nn = length(x_exp);
sigma = 0.25e-1; % Noise variance
Cexp = Cexp.*(1+sigma*randn(nn,1));

u = 0.001;   % Velocity                [m/s]
D = 5000;    % Diffusion coefficient [m^2/s]
L = 100000;  % Length                    [m]
k = 1.40e-6; % Kinetics               [s^-1]

Cin = 10;
tfin = 1;
dci = -20;

% Set figure
figure(1)
set(1,'Position',[18 40 557 355])

%% Run
dC_dz = fminsearch('diffu_LS',dci)

plot(t,C)

% More figure settings
set(gca, 'FontName','Arial', 'Fontsize',12)
hold on
axis(axis)
title('LS solution of the stationary profile')
xlabel('Normalized length')
ylabel('Concentration')

Co = C(end);

plot([0.9 1], [Co Co], '-.r')
text(0.72, Co, ['C_0 = ', num2str(Co)])
plot([0 0.2], [Cin Cin+dC_dz*0.2], '-.r')
text(0.02, 6.4, ['dC_{in} = ', num2str(dC_dz)])