function err = diffu(m)
% 
% Environmental Systems Analysis with Matlab 
% S. Marsili-Libelli
%
%  CRC Press 2016
% ISBN 9781498706353
% Matlab code revised by Emanuele El Basri and Giacomo Barni
% *************************************************************************
%
% This function computes the square error ERR of the boundary conditions 
% for the steady-state diffusive equation between the target final
% concentration C0 and the final concentration C computed using the initial
% condition M.
% 
% *************************************************************************
% 
%    ERR = DIFFU(M)
% 
%    Input:
%           M        Initial condition.
% 
%    Output:
%           ERR      Difference between the target final concentration  Co
%                    and the actual end point of the simulation.
%

%% Call global variables
global tfin u L D dci k Cin Co Cout t C Cexp x_exp

dci = m;

%% Run the simulation
[t, ~, y] = sim('diff_st', tfin);

% Compute the square error
err = (Co - C(end))^2;

%% Figure
figure(1)
hold off
plot(t, C)
hold on
plot(tfin, Co, 'or','MarkerFaceColor','r')
plot(0, Cin, 'or','MarkerFaceColor','r')
drawnow

end