% *************************************************************************
% Environmental Systems Analysis with Matlab 
% S. Marsili-Libelli
%
%  CRC Press 2016
% ISBN 9781498706353
% Matlab code revised by Emanuele El Basri and Giacomo Barni
% *************************************************************************
%
% Simulation of a wastewater treatment plant including the ASM3 kinetic
% model and the Takacs model for the secondary settler.
% The model is fully described in Iacopozzi et al., 2007.
% The Benchmark inputs are used.
%
% Sect. 7.3.3 Fig. 7.47
%
% *************************************************************************

clc 
clear all
close all

%% Load .mat file containing inputs and initial consditions

filename = uigetfile('Input*.mat');	 % Load input data
eval(['load ', filename]);
t_end = t_in(length(t_in));  
tn = 10;           % In order to avoid x_sed error already loaded in Ntot
                   % balance
                             
load cond_iniz.mat % Load initial conditions
                            
%% Load other .m files containing parameters to be passed to the 
%  S-function (MEX)
   
Param_Cstr3_2step  % Initiate Cstr 3 (ASM3_2N model)
Param_Sed3_2step   % Inizializza Settler 3 (Takacs model)
Param_Plant3_2step % Inizializza plant parameters

%% Run simulation
options = simset('RelTol', 1e-1);

tic
[t,x,y] = sim('plant3_2step_base_2v',t_end,options);   
toc

%% Figures
Plots_2step_base 
percentiles