% *************************************************************************
% Environmental Systems Analysis with Matlab 
% S. Marsili-Libelli
%
%  CRC Press 2016
% ISBN 9781498706353
% Matlab code revised by Emanuele El Basri and Giacomo Barni
% *************************************************************************
%
% Computation of the indexes used to assess plant performances.
% Run Go_ASM3_2N_2V.m first.
%
% *************************************************************************

PP = min(find(tsim >= 7)); % Set second week as evaluation start

%% QUALITY INDEX

% Pollutants weights
BTSS = 2;
BCOD = 1;
BBOD = 2;
BTKN = 20;
BNOX = 20;

accum = 0; %                                                          [g/d]
for i = PP:length(tsim)

    TSSe(i,1) = 0.75*(X_out_sed(i,1) + X_out_sed(i,2)) ...
                + 0.9*(X_out_sed(i,3) + X_out_sed(i,5) + X_out_sed(i,6))...
                + 0.6*(X_out_sed(i,4));
    CODe(i,1) = S_out_sed(i,2) + X_out_sed(i,2) + S_out_sed(i,7)...
                + X_out_sed(i,1) + X_out_sed(i,3) + X_out_sed(i,5)...
                + X_out_sed(i,6) + X_out_sed(i,4);
    BODe(i,1) = 0.25*(S_out_sed(i,2) + X_out_sed(i,2)...
                + (1-fxi)*(X_out_sed(i,3) + X_out_sed(i,5)...
                + X_out_sed(i,6) + X_out_sed(i,4)));
    TKNe(i,1) = S_out_sed(i,4) + (S_out_sed(i,2)*INSS)...
                + (S_out_sed(i,7)*INSI) + (X_out_sed(i,2)*INXS)...
                + INBM*(X_out_sed(i,3) + X_out_sed(i,5)...
                + X_out_sed(i,6)) + (X_out_sed(i,1)*INXI);
    SNOXe(i,1) = S_out_sed(i,5) + S_out_sed(i,6);

    accum = accum + ((BTSS*TSSe(i,1)) + (BCOD*CODe(i,1))...
            + (BBOD*BODe(i,1)) + (BTKN*TKNe(i,1))...
            + (BNOX*SNOXe(i,1)))'*Q_out_sed(i,1)*(tsim(i,1) - tsim(i-1,1));      

end

% Effluent Quality
EQ = (1/7000)*accum; %                                               [kg/d]   


%% SLUDGE PRODUCTION

% Compute wasted total suspended solids
accum1 = 0; %                                                           [g]
for i = PP:length(tsim)
    
    accum1 = accum1 + (0.75*(X_w(i,2) + X_w(i,1)) + 0.6*X_w(i,4)...
             + 0.9*(X_w(i,3) + X_w(i,5) + X_w(i,6)))'*Qw*(tsim(i,1)...
             - tsim(i-1,1));   

end
TSSw = accum1/1000; %                                                  [kg]

% Compute wasted sludge
Psludge = TSSw/7; %                                                  [kg/d]

% Compute total suspended solids in the effluent

accum2 = 0; %                                                           [g]
for i = PP:length(tsim)

    accum2 = accum2 + (0.75*(X_out_sed(i,2) + X_out_sed(i,1))...
             + 0.6*X_out_sed(i,4) + 0.9*(X_out_sed(i,3)...
             + X_out_sed(i,5)...
             + X_out_sed(i,6)))'*Q_out_sed(i,1)*(tsim(i,1) - tsim(i-1,1));     

end
TSSef = accum2/1000; %                                                 [kg]

% Computed total produced sludge
Ptot_sludge = Psludge + (TSSef/7); %                                 [kg/d]

%% COMPUTE PUMPING ENERGY

% % accum3 = 0;
% % for i = PP:length(tsim)
% %     accum3 = accum3 + (Qa+Qric+Qw)*(tsim(i,1) - tsim(i-1,1));
% %     
% % end
% % PE = accum3*(0.04/7); % [kWh/d]
% No need to cycle it because it is constant

PE = (0.04/7)*(Qa + Qric + Qw)*7; %                                 [kWh/d]

%% AERATION ENERGY

% KLa = Ka*Ua_aero; % [1/d]   with: Ka [1/mc] and Ua_aero [mc/d] 
KLa_aero1=(Ka*Ua_aero1)/24; %                                         [1/h]

% % accum4 = 0;
% % for i = PP:length(tsim)
% % 
% %     accum4 = accum4 + (0.4032*(KLa_aero1^2) + 7.8408*(KLa_aero1)...
% %              + 0.4032*(KLa_aero2^2) + 7.8408*(KLa_aero2)...
% %              + 0.4032*(KLa_aero3^2) + 7.8408*(KLa_aero3))*(tsim(i,1)...
% %              - tsim(i-1,1));
% %              
% % end
% % AE = accum4*(24/7);  %[kWh/d]
% No need to cycle it because it is constant

AE = (24/7)*(0.4032*(KLa_aero1^2) + 7.8408*(KLa_aero1)); %          [kWh/d]

%% VIOLATIONS ON THE EFFLUENT

%________________________________________
% Constraints:                           |
%                NH4  <= 15  [g-N/mc]    | 
%                NO2  <= 0.6 [g-N/mc]    |
%                NO3  <= 20  [g-N/mc]    |
%                BOD5 <= 25  [g-BOD/mc]  |
%                COD  <= 125 [g-COD/mc]  |
%________________________________________|

% Number of violations of NH4
IN_NH4 = spline(tsim, S_out_sed(:,4), t_in);
for i = 1:length(t_in)
    if IN_NH4(i,1) >= 15
        Violation_NH4(i,1) = 1;
    else
        Violation_NH4(i,1) = 0;
    end
end
N1 = find(Violation_NH4);
V_NH4 = length(N1);

% Number of violations of NO2
IN_NO2 = spline(tsim, S_out_sed(:,5), t_in);
for i = 1:length(t_in)
    if IN_NO2(i,1) >= 0.6
        Violation_NO2(i,1) = 1;
    else
        Violation_NO2(i,1) = 0;
    end
end
N2 = find(Violation_NO2);
V_NO2 = length(N2);

% Number of violations of NO3
IN_NO3 = spline(tsim, S_out_sed(:,6), t_in);
for i = 1:length(t_in)
    if IN_NO3(i,1) >= 20
        Violation_NO3(i,1) = 1;
    else
        Violation_NO3(i,1) = 0;
    end
end
N3 = find(Violation_NO3);
V_NO3 = length(N3);

% Number of violations of BOD5
for i = 1:length(tsim)
    BOD2e(i,1) = 0.25*(S_out_sed(i,2) + X_out_sed(i,2)...
                 + (1-fxi)*(X_out_sed(i,3) + X_out_sed(i,5)...
                 + X_out_sed(i,6) + X_out_sed(i,4)));
end

IN_BOD = spline(tsim, BOD2e(:,1), t_in);
for i = 1:length(t_in)
    if IN_BOD(i,1) >= 25
        Violation_BOD(i,1) = 1;
    else
        Violation_BOD(i,1) = 0;
    end
end
N4 = find(Violation_BOD);
V_BOD = length(N4);

% Number of violations of COD
for i = 1:length(tsim)
    COD2e(i,1) = S_out_sed(i,2) + X_out_sed(i,2) + S_out_sed(i,7)...
                 + X_out_sed(i,1) + X_out_sed(i,3) + X_out_sed(i,5)...
                 + X_out_sed(i,6) + X_out_sed(i,4);
end

IN_COD = spline(tsim, COD2e(:,1), t_in);
for i = 1:length(t_in)
    if IN_COD(i,1) >= 125
        Violation_COD(i,1) = 1;
    else
        Violation_COD(i,1) = 0;
    end
end
N5 = find(Violation_COD);
V_COD = length(N5);

% Time percentage of the violations of NH4
T_NH4 = (V_NH4/length(Violation_NH4))*100; %                            [%]

% Time percentage of the violations of NO2
T_NO2 = (V_NO2/length(Violation_NO2))*100; %                            [%]

% Time percentage of the violations of NO3
T_NO3 = (V_NO3/length(Violation_NO3))*100; %                            [%]

% Time percentage of the violations of BOD5
T_BOD = (V_BOD/length(Violation_BOD))*100; %                            [%]

% Time percentage of the violations of COD
T_COD = (V_COD/length(Violation_COD))*100;% [%]

%% INFLUENT QUALITY

% % Pollutants weights
% BTSS = 2;
% BCOD = 1;
% BBOD = 2;
% BTKN = 20;
% BNOX = 20;

accum6 = 0;
for i = PP:length(tsim)

    TSSi(i,1)  = 0.75*(X_in_imp(i,1) + X_in_imp(i,2))...
                 + 0.9*(X_in_imp(i,3) + X_in_imp(i,5) + X_in_imp(i,6))...
                 + 0.6*(X_in_imp(i,4));
    CODi(i,1)  = S_in_imp(i,2) + X_in_imp(i,2) + S_in_imp(i,7)...
                 + X_in_imp(i,1) + X_in_imp(i,3) + X_in_imp(i,5)...
                 + X_in_imp(i,6) + X_in_imp(i,4);
    BODi(i,1)  = 0.65*(S_in_imp(i,2) + X_in_imp(i,2)...
                 + (1-fxi)*(X_in_imp(i,3) + X_in_imp(i,5)...
                 + X_in_imp(i,6) + X_in_imp(i,4)));
    TKNi(i,1)  = S_in_imp(i,4) + (S_in_imp(i,2)*INSS)...
                 +(S_in_imp(i,7)*INSI) + (X_in_imp(i,2)*INXS)...
                 + INBM*(X_in_imp(i,3) + X_in_imp(i,5) + X_in_imp(i,6))...
                 + (X_in_imp(i,1)*INXI);
    SNOXi(i,1) = S_in_imp(i,5) + S_in_imp(i,6);

    accum6 = accum6 + ((BTSS*TSSi(i,1)) + (BCOD*CODi(i,1))...
             + (BBOD*BODi(i,1)) + (BTKN*TKNi(i,1))...
             + (BNOX*SNOXi(i,1)))'*Q_ing_sim(i,1)*(tsim(i,1)-tsim(i-1,1));
             %                                                        [g/d]
end

IQ = (1/7000)*accum6; %                                              [kg/d]

% Quality percentual variation
dE = 100*(IQ - EQ)/IQ;

%% Print results
clc
disp('-------------------------------------------------------------------')
disp('-----------------PLANT PERFORMANCE IN THE 2ND WEEK-----------------')
disp('-------------------------------------------------------------------')
disp(['Effluent Quality (EQ)          = ', num2str(EQ)])
disp(['Influent Quality (IQ)          = ', num2str(IQ)])
disp(['Quality improvement            = ', num2str(dE),' %'])
disp('-------------------------------------------------------------------')
disp(['Total sludge production (Ptot) = ', num2str(Ptot_sludge),' [kg/d]'])
disp(['Pumping energy  (PE)           = ', num2str(PE),' [kWh/d]'])
disp(['Aeration energy (AE)           = ', num2str(AE),' [kWh/d]'])
disp('-------------------------------------------------------------------')
disp('----------------------PERCENTUAL VIOLATIONS------------------------')
disp(['Violations NH4                 = ', num2str(T_NH4),'  %'])
disp(['Violations NO2                 = ', num2str(T_NO2),'  %'])
disp(['Violations NO3                 = ', num2str(T_NO3),'  %'])
disp(['Violations BOD                 = ', num2str(T_BOD),'  %'])
disp(['Violations COD                 = ', num2str(T_COD),'  %'])
disp('-------------------------------------------------------------------')