% *************************************************************************
% Environmental Systems Analysis with Matlab 
% S. Marsili-Libelli
%
%  CRC Press 2016
% ISBN 9781498706353
% Matlab code revised by Emanuele El Basri and Giacomo Barni
% *************************************************************************
%
% This script plots the results of 'Go_ASM3_2N_2V.m'.
%
% *************************************************************************

%% STATE VARIABLES OF THE BIOLOGICAL MODEL_________________________________
%
% S(1)  = SO2   Dissolved oxygen                                 [g/m^3 DO] 
% S(2)  = SS    Rapidely biodegradable organic substrate        [g/m^3 COD]
% S(3)  = SN2g  Gas organic nitrogen                              [g/m^3 N]
% S(4)  = SNH4  Ammoniacal nitrogen + ammonia ions                [g/m^3 N]
% S(5)  = SNO2  Nitrites                                          [g/m^3 N]
% S(6)  = SNO3  Nitrates                                          [g/m^3 N]
% S(7)  = SI    Inert soluble organic material                  [g/m^3 COD]
% S(8)  = SALK  Alkalinity (=392 gr/m^3)                     [mol HCO3/m^3]
% S(9)  = XI    Inert particulate material                      [g/m^3 COD]
% S(10) = XS    Slowly biodegradable substrate                  [g/m^3 COD]
% S(11) = XH    Heterotrophic biomass                           [g/m^3 COD]
% S(12) = XSTO  Internal biomass stocking product               [g/m^3 COD]
% S(13) = Xns   Nitrosomonas autotrophic biomass                [g/m^3 COD]
% S(14) = Xnb   Nitrobacter autotrophic biomass                 [g/m^3 COD]
%__________________________________________________________________________

close all

%%    PLANT INPUTS
figure(1)
set(gcf, 'Position', [13 38 784 479])

subplot(311)
plot(t_in, Q_in, 'b', 'LineWidth',2)
set(gca, 'FontName','Arial', 'FontSize',12)
ylabel('Q_{in} [mc/d]')
title('Inputs')

subplot(312)
plot(t_in, COD_in, 'm', 'LineWidth',2)
set(gca, 'FontName','Arial', 'FontSize',12)
ylabel('COD_{in} [mg/L]')

subplot(313)
plot(t_in, SNH4_in, 'r', 'LineWidth',2)
set(gca, 'FontName','Arial', 'FontSize',12)
ylabel('S_{NH_4^+in} [mg/L]')
xlabel('time [d]')

%%    ANOXIC TANK 1 INPUTS
Tstart = 30;
np = Tstart:length(tsim);


figure(2)
set(gcf, 'Position',[13 38 784 479])
Tstart = 20;

subplot(211)
plot(tsim(np), S_ing_anox1(np,2), 'r', tsim(np), S_ing_anox1(np,7), 'b',...
     'LineWidth',2)
set(gca, 'FontName','Arial', 'FontSize',12)
legend('S_S', 'S_I', 'Orientation','horizontal')
ylabel('[mg-COD/L]')
title('Solubles anoxic tank input')

subplot(212)
plot(tsim(np), S_ing_anox1(np,4), 'm', tsim(np),S_ing_anox1(np,5), 'r',...
     tsim(np), S_ing_anox1(np,6), 'b', 'LineWidth',2)
set(gca, 'FontName','Arial', 'FontSize',12)
legend('S_{NH_4^+}', 'S_{NO_2^-}', 'S_{NO_3^-}', 'Orientation','horizontal')
title('Nitrogen anoxic tank input')
ylabel('[mg-N/L]')
xlabel('time [d]')

figure(22)
set(gcf, 'Position',[13 38 784 479])
subplot(211)
plot(tsim(np), S_ing_anox1(np,4), 'r',tsim(np), S_out_anox1(np,4), 'b',...
     'LineWidth',2)
set(gca, 'FontName','Arial', 'FontSize',12)
legend('Input', 'Output', 'Orientation','horizontal')
ylabel('S_{NH_4^+} [mg-N/L]')

subplot(212)
plot(tsim(np), S_ing_anox1(np,6), 'r', tsim(np), S_out_anox1(np,6), 'b',...
     'LineWidth',2)
set(gca, 'FontName','Arial', 'FontSize',12)
legend('Input', 'Output', 'Orientation','horizontal')
ylabel('S_{NO_3^-} [mg-N/L]')
xlabel('time [d]')


figure(3)
set(gcf, 'Position',[13 38 784 479])
subplot(311)
plot(tsim, X_ing_anox1(:,1), 'b', tsim, X_ing_anox1(:,2), 'r',...
     'LineWidth',2)
set(gca, 'FontName','Arial', 'FontSize',12)
legend('X_I', 'X_S', 'Orientation','horizontal')
title('Particulate anoxic tank input')
ylabel('[mg-COD/L]')

subplot(312)

plot(tsim(np), X_ing_anox1(np,5), 'r', tsim(np), X_ing_anox1(np,6), 'b',...
     'LineWidth',2)
set(gca, 'FontName','Arial', 'FontSize',12)
legend('X_{ns}', 'X_{nb}', 'Orientation','horizontal')
title('Autotrophic biomass anoxic tank input')
ylabel('[mg-COD/L]')

subplot(313)
plot(tsim,X_ing_anox1(:,3), 'b', tsim, X_ing_anox1(:,4), 'r',...
     'LineWidth',2)
set(gca, 'FontName','Arial', 'FontSize',12)
legend('X_S', 'X_{STO}', 'Orientation','horizontal')
title('Heterotrophic biomass anoxic tank input')
ylabel('[mg-COD/L]')
xlabel('time [d]')

%%    ANOXIC TANK OUT / AEROBIC TANK IN
figure(4)
set(gcf, 'Position', [13 38 784 479])
subplot(211)
plot(tsim, S_out_anox1(:,4), 'm', tsim, S_out_anox1(:,5), 'r',...
     tsim, S_out_anox1(:,6), 'b', 'LineWidth',2)
set(gca, 'FontName','Arial', 'FontSize',12)
title('Nitrogen anoxic tank output')
legend('S_{NH_4^+}', 'S_{NO_2^-}','S_{NO_3^-}', 'Orientation','horizontal')
ylabel('[mg-N/L]')

subplot(212)
plot(tsim(np), S_out_anox1(np,2), 'r', tsim(np), S_out_anox1(np,1), 'b',...
     'LineWidth',2)
set(gca, 'FontName','Arial','FontSize',12)
legend('S_S', 'S_{O_2}', 'Orientation','horizontal')
title('Solubles anoxic tank output')
ylabel('[mg-COD/L]')
xlabel('time [d]')


figure(5)
set(gcf, 'Position',[13 38 784 479])

subplot(311)
plot(tsim(np), X_out_anox1(np,1), 'b', tsim(np), X_out_anox1(np,2), 'r',...
     'LineWidth',2)
set(gca, 'FontName','Arial', 'FontSize',12)
legend('X_I', 'X_S', 'Orientation','horizontal')
title('Particulate anoxic tank output')
ylabel('[mg-COD/L]')

subplot(312)
plot(tsim(np), X_out_anox1(np,5), 'r', tsim(np), X_out_anox1(np,6), 'b',...
     'LineWidth',2)
set(gca, 'FontName','Arial', 'FontSize',12)
legend('X_{ns}', 'X_{nb}', 'Orientation','horizontal')
ylabel('[mg-COD/L]')
title('Autotrophic biomass anoxic tank output')

subplot(313)
plot(tsim(np), X_out_anox1(np,3), 'b', tsim(np), X_out_anox1(np,4), 'r',...
     'LineWidth',2)
set(gca, 'FontName','Arial', 'FontSize',12)
legend('X_H', 'X_{STO}', 'Orientation','horizontal')
title('Heterotrophic biomass anoxic tank output')
ylabel('[mg-COD/L]')
xlabel('time [d]')


figure(6)
set(gcf, 'Position',[13 38 784 479])
Tstart = 70;
np = Tstart:length(tsim);

plot(tsim(np), S_out_anox1(np,3), 'b', tsim(np), S_out_aero1(np,3), 'r',...
     'LineWidth',2)
set(gca, 'FontName','Arial', 'FontSize',12)
legend('N_2 out anox', 'N_2 out', 'Orientation','horizontal')
title('Molecular nitrogen')
ylabel('[mg-N_2/L]')
xlabel('time [d]')

%%     AEROBIC TANK OUT / SETTLER IN
Tstart = 30;
np = Tstart:length(tsim);

figure(7)
set(gcf, 'Position',[13 38 784 479])

subplot(211)
plot(tsim(np), S_out_aero1(np,1), 'b', tsim(np), S_out_aero1(np,2), 'r',...
     'LineWidth',2)
set(gca, 'FontName','Arial', 'FontSize',12)
legend('S_O', 'S_S', 'Orientation','horizontal')
ylabel('[mg-COD/L]')
title('Solubles aerobic tank output')

subplot(212)
plot(tsim(np), S_out_aero1(np,4), 'm', tsim(np), S_out_aero1(np,5), 'r',...
     tsim(np), S_out_aero1(np,6), 'b', 'LineWidth',2)
set(gca, 'FontName','Arial', 'FontSize',12)
title('Nitrogen aerobic tank output')
legend('S_{NH_4^+}', 'S_{NO_2^-}','S_{NO_3^-}', 'Orientation','horizontal')
ylabel('[mg-N/L]')
xlabel('time [d]')


figure(8)
set(gcf, 'Position',[13 38 784 479])
subplot(311)
plot(tsim, X_out_aero1(:,1), 'b', tsim, X_out_aero1(:,2), 'r',...
     'LineWidth',2)
set(gca,'FontName','Arial', 'FontSize',12)
legend('X_I', 'X_S','Orientation','horizontal')
title('Particulate aerobic tank output')
ylabel('[mg-COD/L]')

subplot(312)
plot(tsim(np), X_out_aero1(np,5), 'r', tsim(np), X_out_aero1(np,6), 'b',...
     'LineWidth',2)
set(gca, 'FontName','Arial', 'FontSize',12)
legend('X_{ns}', 'X_{nb}', 'Orientation','horizontal')
ylabel('[mg-COD/L]')
title('Autotrophic biomass aerobic tank output')

subplot(313)
plot(tsim(np), X_out_aero1(np,3), 'b', tsim(np), X_out_aero1(np,4), 'r',...
     'LineWidth',2)
set(gca, 'FontName','Arial', 'FontSize',12)
legend('X_H', 'X_{STO}', 'Orientation','horizontal')
title('Heterotrophic biomass aerobic tank output')
ylabel('[mg-COD/L]')
xlabel('time [d]')

 %%   SETTLER OUTPUT
figure(9)
set(gcf, 'Position',[13 38 784 479])

subplot(311)
plot(tsim(np), COD_out(np), 'b', 'LineWidth',2)
set(gca, 'FontName','Arial', 'FontSize',12)
title('COD output')
ylabel('[mg-COD/L]')

subplot(312)
plot(tsim(np), X_out_sed(np), 'b', 'LineWidth',2)
set(gca, 'FontName','Arial', 'FontSize',12)
title('Total solids output')
ylabel('X_{TOT} [mg-COD/L]')

subplot(313)
plot(tsim(np), S_out_aero1(np,4), 'm', tsim(np), S_out_aero1(np,5), 'r',...
     tsim(np), S_out_aero1(np,6), 'b', 'LineWidth',2)
set(gca, 'FontName','Arial', 'FontSize',12)
title('Nitrogen output')
legend('S_{NH_4^+}', 'S_{NO_2^-}', 'S_{NO_3^-}', 'Orientation','horizontal')
ylabel('[mg-N/L]')
xlabel('time [d]')


%%    PLANT OUTPUTS
figure(10)
set(gcf, 'Position',[13 38 784 479])

subplot(311)
plot(tsim(np), X_out_sed(np,1), 'b', tsim(np), X_out_sed(np,2), 'r',...
     'linewidth',2)
set(gca, 'FontName','Arial', 'FontSize',12)
legend('X_I', 'X_S', 'orientation','horizontal')
title('Particulate settler output')
ylabel('[mg-COD/L]')

subplot(312)
plot(tsim(np), X_out_sed(np,5), 'r', tsim(np), X_out_sed(np,6), 'b',...
     'LineWidth',2)
set(gca, 'FontName','Arial', 'FontSize',12)
legend('X_{ns}', 'X_{nb}', 'orientation','horizontal')
ylabel('[mg-COD/L]')
title('Autotrophic biomass settler output')

subplot(313)
plot(tsim(np), X_out_sed(np,3), 'b', tsim(np), X_out_sed(np,4), 'r',...
     'LineWidth',2)
set(gca, 'FontName','Arial', 'FontSize',12)
legend('X_H', 'X_{STO}', 'orientation','horizontal')
title('Heterotrophic biomass settler output')
ylabel('[mg-COD/L]')
xlabel('time [d]')

%%    RECYCLE FROM SETTLER
figure(11)
set(gcf,'Position',[13 38 784 479])

subplot(211);
plot(tsim(np), S_ric_sed(np,4), 'm', tsim(np), S_ric_sed(np,5), 'r',...
     tsim(np), S_ric_sed(np,6), 'b', 'LineWidth',2)
set(gca, 'FontName','Arial', 'FontSize',12)
legend('S_{NH_4^+}', 'S_{NO_2^-}', 'S_{NO_3^-}', 'orientation','horizontal')
ylabel('[mg-N/L]')
title('Nitrogen recycled from settler')

subplot(212);
plot(tsim(np), S_ric_sed(np,1), 'b', tsim(np), S_ric_sed(np,2), 'r',...
     'LineWidth',2)
set(gca, 'FontName', 'Arial','FontSize',12)
title('Solubles recycled from settler')
legend('S_O', 'S_S', 'Orientation','horizontal')
ylabel('[mg-COD/L]')
xlabel('time [d]')


figure(12)
set(gcf, 'Position',[13 38 784 479])

subplot(311);
plot(tsim(np), X_ric_sed(np,1), 'b', tsim(np), X_ric_sed(np,2), 'r',...
     'LineWidth',2)
set(gca, 'FontName','Arial', 'FontSize',12)
legend('X_I', 'X_S', 'Orientation','horizontal')
title('Particulate recycle')
ylabel('[mg-COD/L]')

subplot(312)
plot(tsim(np), X_ric_sed(np,5), 'r', tsim(np), X_ric_sed(np,6), 'b',...
     'LineWidth',2)
set(gca, 'FontName','Arial', 'FontSize',12)
legend('X_{ns}', 'X_{nb}', 'Orientation','horizontal')
ylabel('[mg-COD/L]')
title('Autotrophic biomass recycle')

subplot(313);
plot(tsim(np), X_ric_sed(np,3), 'b', tsim(np), X_ric_sed(np,4), 'r',...
     'LineWidth',2)
set(gca, 'FontName','Arial', 'FontSize',12)
legend('X_H', 'X_{STO}', 'Orientation','horizontal')
title('Heterotrophic biomass recycle')
ylabel('[mg-COD/L]')
xlabel('time [d]')