function percentile(par, nfig, lim, lbl)
% 
% Environmental Systems Analysis with Matlab 
% S. Marsili-Libelli
%
%  CRC Press 2016
% ISBN 9781498706353
% Matlab code revised by Emanuele El Basri and Giacomo Barni
% ********************************************************
%
% This function computes the percentiles of the selected parameter Y of the
% ASM3 model and plots the result on the figure NFIG.
% 
% ********************************************************
% 
%          PERCENTILE(PAR, NFIG, LIM, LBL)
% 
%    Input:
%           PAR      Parameter of the ASM3 model.
%
%           NFIG     Number of figure on which plot the results.
%
%           LIM      Normative concentration limit or the parameter PAR.
%
%           LBL      Parameter label to be used in the plot.
% 
%
%%

%% Initialize figure
figure(nfig)
set(gcf, 'Position', [13 38 784 479])

%% Subplot 1: Relative frequency
maxy = max(par);
maxy = max(maxy, lim);
assex = 0:maxy/80:maxy*1.1;
IA = histc(par, assex);
IAF = IA/length(par);

subplot(121)
bar(assex, IAF)
axis tight
xlabel(lbl)
ylabel('Relative frequency')

%% Subplot 2: Cumulative frequency
IAC = cumsum(IAF);
i = find(assex >= lim);
i = min(i);
Imax = 100*IAC(i);

subplot(122)
plot(assex, IAC*100)
axis tight
hold on
xlabel(lbl)
ylabel('Cumulative frequency')
plot([lim lim], [0 Imax], ':r')
plot([0 lim], [Imax Imax], ':r')
% axis tight
end