%% ************************************************************************
%
% Environmental Systems Analysis with Matlab 
% S. Marsili-Libelli
%
%  CRC Press 2016
% ISBN 9781498706353
% Matlab code revised by Emanuele El Basri and Giacomo Barni
% *************************************************************************
% 
% Simulation of the competition between two bacterial populations on the 
% basis of their growth characteristics.
% 
% Sect. 7.1.2
%
% *************************************************************************

clear
close all
clc
%%
% Set global variables
global Mu1 Mu2 Ks1 Ks2

S = 0:0.15:100; % Substrate

% Kinetic parameters of the first population.
Mu1 = 0.35;
Ks1 = 20;
Y1  = 0.4;
Kd1 = 0.01;

% Reaction rate of the first population
M1 = Mu1*S./(Ks1+S); 

% Kinetic parameters of the second population.
Mu2 = 0.6;
Ks2 = 80;
Y2  = 0.5;
Kd2 = 0.02;

% Reaction rate of the second population
M2 = Mu2*S./(Ks2+S);

figure(1)
set(1,'Position',[23 48 560 420])
plot(S,M1,'b', S,M2,':b','LineWidth',2)
legend('Pop 1', 'Pop 2', 'location','north', 'orientation','horizontal')

% Search optimal concentration of the substrate
S_opt=fminsearch('Double_Monod',40);

hold on

% Equilibrium reaction rate
M_opt = Mu1*S_opt/(Ks1+S_opt);

plot([S_opt S_opt], [0 M_opt], ':r','LineWidth',1)
plot([0 S_opt], [M_opt M_opt], ':r','LineWidth',1)

xlabel('Substrate [mg/L]')
ylabel('Reaction rate [1/h]')
text(S_opt, M_opt, ['   Optimal Substrate = ',num2str(S_opt)], ...
    'VerticalAlignment','top')