%% ************************************************************************
%
% Environmental Systems Analysis with Matlab 
% S. Marsili-Libelli
%
%  CRC Press 2016
% ISBN 9781498706353
% Matlab code revised by Emanuele El Basri and Giacomo Barni
% *************************************************************************
% 
% Simulation of two microbial models, one following the Monod kinetics, the
% other the Haldane kinetics.
% 
% Sects. 7.1.2 and 7.1.3
%
% *************************************************************************

clear
close all
clc

%% Insert data
prompt = {'Maximum growth rate (max)', 'Half-velocity constant (Ks)',...
          'Yield factor (Y)', 'Endogenous metabolism rate (bH)',...
		  'Haldane''s self-inhibition constant (Ki)',...
		  'Initial substrate (So)', 'Initial biomass (Xo)',...
		  'Simulation length'};
% Default values
def = {'0.5', '120', '0.5', '0.05', '75', '100', '0.5', '80'};
data = inputdlg(prompt, 'Monod and Haldane kinetics', 1, def);

data = char(data);
Mmax = str2num(data(1,:));
Ks   = str2num(data(2,:));
Yc   = str2num(data(3,:));
bH   = str2num(data(4,:));
Ki   = str2num(data(5,:));
Smo  = str2num(data(6,:));
Xmo  = str2num(data(7,:));
tend = str2num(data(8,:));
Y   = Yc;
Sho = Smo;
Xho = Xmo;

%% Run simulations
%  Monod
[tm, x, y] = sim('Batch_Monod', tend);
%  Haldane
[th, x, y] = sim('Batch_Haldane', tend);

%% Figures
figure(1)
set(1, 'Position',[38 46 714 453])
% Monod model
subplot(211)
plot(tm,S_m,'b', tm, X_m,':b')
title('Monod model')
ylabel('Conc. [mg/L]')
xlabel('time [min]')
legend('Substrate', 'Biomass')
% Haldane model
subplot(212)
plot(th,S_h,'b', th,X_h,':b')
title('Haldane model')
ylabel('Conc. [mg/L]')
xlabel('time [min]')
legend('Substrate', 'Biomass')