%% ************************************************************************
%
% Environmental Systems Analysis with Matlab
% S. Marsili-Libelli
%
%  CRC Press 2016
% ISBN 9781498706353
% Matlab code revised by Emanuele El Basri and Giacomo Barni
% *************************************************************************
%
% Simulation of the basic Michaelis-Menten kinetics to demonstrate the
% importance of the activated complex ES* depending on the initial enzyme
% concentration.
%
% Sect. 7.1.2
%
%% ************************************************************************

clear
close all
clc

ESS = 1;
%% Select the enzyme initial concentration Eo
switch ESS
    case 1% Initial conditions to simulate the lack of steady-state for ES*
        Eo   = 10;  % Initial enzyme
        So   = 10;  % Initial substrate
        tend = 6;
        
    case 2% Initial conditions to simulate the steady-state for ES*
        Eo   = 0.1; % Initial enzyme
        So   = 10;  % Initial substrate
        tend = 600;
end

%% Other initial conditions
ESo = 0;
Po  = 0;

%% Kinetic constants
K1 = 1;
K2 = 4;
K3 = 1;
% Note that the half-velocity constant Ks = (K2+K2)/K1 = 5

%% Run simulation
[t, x, y] = sim('MM_basic', tend);

%% Figure
figure(1)
set(1, 'Position',[38 46 798 395])
plot(t,S,t,ES,':b', t,P,'-.b')
set(gca, 'FontName','Arial', 'FontSize',14)
title(['E_0/S_0 = ', num2str(Eo/So)])
ylabel('Conc. [mg/L]')
xlabel('time [min]')
legend('S', 'ES^*', 'P')