% *************************************************************************
%
% Environmental Systems Analysis with Matlab 
% S. Marsili-Libelli
%
%  CRC Press 2016
% ISBN 9781498706353
% Matlab code revised by Emanuele El Basri and Giacomo Barni
% *************************************************************************
% 
% Compute the Haldane kinetic rate as a function of substrate.
% 
% Sect. 7.1.3 Fig. 7.4
%
% *************************************************************************

clear
close all
clc
 
 %% Define the kinetic parameters
S  = 0:0.1:30;
Ks = 10;
Ki = 2;
Mu_max = 4.5;
Mu = Mu_max*(1./(1+(Ks./S) + (S/Ki)));

im  = find(Mu == max(Mu));
Mum = Mu(im);
Sm  = S(im);

%% Figures
figure(1)
set(1, 'Position',[38 46 938 431])
set(gca, 'FontName','Arial', 'FontSize',14)
plot(S, Mu, 'b', 'Linewidth',2)
xlabel('Substrate [mg/L]')
ylabel('Reaction rate [1/h]')

hold on
plot([Sm Sm],[0 Mum],':b')
TX=text(Sm, Mum/2, ['S_m_a_x = ',num2str(Sm)],...
        'HorizontalAlignment','center', 'BackgroundColor','w');
set(TX, 'FontName','Arial', 'FontSize',12)
% axis([0 30 0 0.6])
% plot([0 30],[Mu_max Mu_max],':b')