% *************************************************************************
%
% Environmental Systems Analysis with Matlab 
% S. Marsili-Libelli
%
%  CRC Press 2016
% ISBN 9781498706353
% Matlab code revised by Emanuele El Basri and Giacomo Barni
% *************************************************************************
%
% Launch script for the Cell-quota model.
% (Droop, 1983)
%
% Sect. 7.4.1.1 and Fig. 7.52
%
% *************************************************************************

clear
close all
clc

%% Set parameters
Po = 15;      % Initial nutrient concentration
%  Parameter vector bundle
Um = 0.042;   % Uptake maximum rate
Mq = 0.001;   % Cell-quota maximum rate
kq = 1.5;     % Cell-quota constant
ks = 15;      % Uptake half-velocity
kd = 0.00013; % Biomass decay rate
Xo = 0.3;     % Initial biomass
Qo = 0.0015;  % Initial cell-quota
Y  = 0.75;    % Yield factor

%% Run simulation
tfin = 10000; % Final simulation time
Dec  = 10;    % Simulation data decimation factor
[t, x, y] = sim('Cell_Quota', tfin);

%% Figures
figure(1)
set(gcf, 'Position',[18 54 720 451])
plot(ts/3600,S,'-.b', ts/3600,Q,'b', ts/3600,X,':b', 'Linewidth',2)
set(gca,'FontName','Arial','FontSize',14)
legend('Ext. Substrate', 'Cell-Quota', 'Biomass', 'location','northeast')
xlabel('time [h]')
ylabel('Concentration [mg/L]')
axis tight