%% ************************************************************************
%
% Environmental Systems Analysis with Matlab
% S. Marsili-Libelli
%
%  CRC Press 2016
% ISBN 9781498706353
% *************************************************************************
%
%  Fitting the carrying capacity surface of several S. capricornutum
%  batches as a function of the added quantities of N and P
%
%  Sect. 8.6.1.1 and Fig. 8.45
%
% *************************************************************************

clear
close all
clc

%% Global parameters definition
global Ak Kn Kp n p G
% Experimental data
% Try calibrating the surface using either of these data sets one at a time
% Un-comment the data set which you want to use for the calibration
% Afinal=[450000 716000 820000 442000 922000 1186000 470000 918000 1432000]; % Apr. 97
%Kn =5.6278 Kp = 0.1681 G = 1.5098

Afinal=[401000 668000 670000 397000 820000 1174900 403000 756000 1321000]; % Febr. 97 
%Kn =10.1047 Kp=0.3203 G 2.3131

Ak=reshape(Afinal,3,3);
Ak=Ak'
Ak=Ak/1e7;
% Defining the N/P grid
% according to the added
% nutrient quantities
N=[0.22 0.44 0.88];
P=[0.02 0.04 0.08];
[n p]=meshgrid(N,P)
% Initial values of global parameters
Par=[5 0.7 1]';  
options(1)=1;
options(14)=2000;
% Surface identification
[ParCal,options]=Simplex('K_Error',Par,options);
ParBest=ParCal; % Estimated parameters are here
Kn=ParBest(1);Kp=ParBest(2);G=ParBest(3);
% Plotting the fitted grid
nn=[0.22:(0.88-0.22)/30:0.88];pp=[0.02:(0.08-0.02)/30:0.08];
[Nn,Pp]=meshgrid(nn,pp);
N1=Nn./(Kn+Nn);P1=Pp./(Kp+Pp);
M=G./((1./N1)+(1./P1));
N1=n./(Kn+n);P1=p./(Kp+p);
Mm=G./((1./N1)+(1./P1));nn=[0.22:(0.88-0.22)/30:0.88];pp=[0.02:(0.08-0.02)/30:0.08];
[Nn,Pp]=meshgrid(nn,pp);
N1=Nn./(Kn+Nn);P1=Pp./(Kp+Pp);
M=G./((1./N1)+(1./P1));
N1=n./(Kn+n);P1=p./(Kp+p);
Mm=G./((1./N1)+(1./P1));
figure(1)
set(1,'Position',[26 45 680 500])
surf(Nn,Pp,M)
hold on
shading interp
plot3(n,p,Ak+0.0002,'or','MarkerFaceColor','r','MarkerSize',8);
plot3(n,p,Mm+0.0008,'sb','MarkerFaceColor','b','MarkerSize',8);
plot3(0.25,0.08,.156,'or','MarkerFaceColor','r','MarkerSize',8);
plot3(0.25,0.08,.14,'sb','MarkerFaceColor','b','MarkerSize',8);
text(0.25,0.08,0.156,'  Obs. Max. dens.')
text(0.25,0.08,0.14,'  Fitted Max. dens.')

xlabel('N (mg L^-^1)')
ylabel('P (mg L^-^1)')
title('Fitting the carrying capacity to the observed max. opt. dens.')
zlabel('Cell density (10^7 cell mL^-^1)')
