%% ************************************************************************
%
% Environmental Systems Analysis with Matlab
% S. Marsili-Libelli
%
%  CRC Press 2016
% ISBN 9781498706353
% *************************************************************************
%
%  This exercise calibrates a Richards growth model (Sect. 5.1.4) to the
%  optical density data representing the growth of a batch of Selenastrum
%  capricornutum single-cell growth batch.
%
%  See Sect. 8.6.1 and Fig. 8.43
%
% *************************************************************************

clear
close all
clc
%%
% Global parameters definition
global r K n tfin Data_Sperim tx Go ys1
% Observation times (h)
tx=[0 78 104 125 149 172.5 197 221 228 245 271 295];

tfin=295;Go=0.001;


% Try several model calibrations using these data sets one at a time
% Un-comment the data set which you want to use for the calibration
%Data set #1
Data_Sperim=[0.001 0.03 0.038 0.044 0.047 0.047 0.048 0.049 0.049 0.047 0.047 0.047];
%Data set #2
%Data_Sperim=[0.001 0.04 0.052 0.063 0.068 0.070 0.074 0.075 0.074 0.075 0.075 0.075];
%Data set #3
%Data_Sperim=[0.001 0.037 0.055 0.070 0.074 0.075 0.076 0.077 0.076 0.075 0.075 0.075];
%Data set #5
%Data_Sperim=[0.001 0.056 0.070 0.081 0.085 0.087 0.089 0.091 0.091 0.090 0.090 0.090];
%Data set #6
% Data_Sperim=[0.001 0.061 0.078 0.098 0.112 0.122 0.126 0.131 0.131 0.131 0.132 0.131];
%Data set #7
%Data_Sperim=[0.001 0.032 0.039 0.045 0.047 0.046 0.047 0.044 0.044 0.046 0.045 0.046];
%Data set #8
%Data_Sperim=[0.001 0.05 0.065 0.077 0.081 0.083 0.083 0.083 0.083 0.081 0.082 0.081];
%Data set #9
%Data_Sperim=[0.001 0.053 0.067 0.081 0.104 0.123 0.131 0.136 0.138 0.141 0.144 0.144];


% Initial parameter estimates
Par=[0.03 0.081 -0.0148]'; 
% Setting up the Simplex options
options=foptions;
options(1)=2;
options(2)=0.01;
options(3)=0.01;
options(14)=500;
[ParCal,options]=simplex('F_Selen',Par);
ParBest=ParCal; % Estimated parameters are here
% Plot the results
figure(1)
set(1,'Position',[26 45 560 420])

xlabel('time (h)')
ylabel('Optical density')
legend('Richards model','Data','location','e')
title('Calibration of the Richards model to a set of S. capricurnutum batch growth data')
a=axis;
text(150,0.33*(a(4)-a(3)),['r = ',num2str(r)])
text(150,0.28*(a(4)-a(3)),['K = ',num2str(K)])
text(150,0.23*(a(4)-a(3)),['n = ',num2str(n)])