%% ************************************************************************
%
% Environmental Systems Analysis with Matlab
% S. Marsili-Libelli
%
%  CRC Press 2016
% ISBN 9781498706353
% 
% *************************************************************************
%
% Calibration of the total daily radiation according to Eq. (8.5)
% using experimental data. The daily global solar radiation data were
% computed by the ENEA website 
%
% http://www.solaritaly.enea.it/CalcRggmmOrizz/Calcola1.php
%
% for a location of 43.7N, 11E, corrsponding 
% to the town of Florence, Italy
%
% Sect. 8.1.3
%
% *************************************************************************

clear
clc
close all
%% Global parameters definition
global days Ia Ia_stima
% Experimental data from the ENEA website (Wh/m^2)
days=[16 44 75 105 136 166 197 228 258 289 319 350];
Ia=[1744.9 2488.2 3769.4 4719.9 5904.5 6481.5 6285.0 5509.5 4244.3 2884.7 1894.3 1426.7];
% Initial parameter estimates
Par=[3949.5 2504.6 0.0172 -26.54];

figure(1)
set(1,'Position',[46 37 675 444])
% Error function minimization

options=foptions;
options(1)=1;
options(2)=0.05;
options(3)=0.05;
options(14)=5000;
[ParCal,options]=simplex('FERR_SolRad',Par,options);
ParCal


figure(1)
hold on
d=0:365;
Iaa=ParCal(1)+ParCal(2)*sin(ParCal(3)*d+ParCal(4));
plot(d,Iaa,':r')
xlim([0 365])
legend('Sol Rad data','Model fit','Full model response')