function R = Ellipse_Corr(X)
% 
% Environmental Systems Analysis with Matlab 
% S. Marsili-Libelli
%
%  CRC Press 2016
% ISBN 9781498706353
% Matlab code revised by Emanuele El Basri and Giacomo Barni
% *************************************************************************
% 
% This function plot the confidence ellipse for the data in the input 
% matrix X and computes his correlation matrix.
%
% *************************************************************************
% 
%      R = ELLIPSE_CORR(X)
% 
%    Input:
%           X        An array containing the data.
% 
%    Output:
%           R        The correlation matrix of the input data X.
%

%% Compute the correlation
[n m] = size(X);
R = corr(X);

%% Compute the ellipse
[v, e] = eig(R);
L = diag(e);
fi = [0:0.001:2*pi];
pH = ones(2,length(fi));
for i = 1:length(fi);
    pH(:,i) = v*e*[cos(fi(i)); -sin(fi(i))];
end

op = 1.25*max(max(pH));

%% Plot the ellipse
figure(2)
plot(pH(1,:), pH(2,:), 'b')
hold on
axis([-op op -op op])
 axis square
az = axis;

set(gca, 'FontName','Arial', 'FontSize',12)
xlabel('x_1')
ylabel('x_2')
hold on

plot(R(1,1), R(1,2), 'or')
plot(R(2,1), R(2,2), 'or')
text(R(1,1), R(2,1), ['   ', num2str(R(2,1))])
plot([0, L(1)*v(1,1)], [0,L(1)*v(1,2)], ':r')
plot([0, L(2)*v(2,1)],[0,L(2)*v(2,2)],':r')
plot([az(1) az(2)], [0 0], 'k')
plot([0 0], [az(3) az(4)], 'k')
plot([az(1) az(2)], [1 1], ':k')
plot([1 1], [az(3) az(4)], ':k')
plot([az(1) az(2)], [-1 -1], ':k')
plot([-1 -1], [az(3) az(4)], ':k')

end