function C = Ellipse_Cov(X)
% 
% Environmental Systems Analysis with Matlab 
% S. Marsili-Libelli
%
%  CRC Press 2016
% ISBN 9781498706353
% Matlab code revised by Emanuele El Basri and Giacomo Barni
% *************************************************************************
% 
% This function plot the confidence ellipse for the data in the input 
% matrix X and computes his covariance matrix.
%
% *************************************************************************
% 
%      C = ELLIPSE_COV(X)
% 
%    Input:
%           X        An array containing the data.
% 
%    Output:
%           C        The covariance matrix of the input data X.
%

%% Compute the covariance
[n m] = size(X);
C = cov(X);

%% Compute the ellipse
[v, e] = eig(C);
L(1) = 1.96*sqrt(e(1,1));
L(2) = 1.96*sqrt(e(2,2));
E = diag(L);
fi = [0:0.001:2*pi];
pH = ones(2, length(fi));
for i = 1:length(fi);
    pH(:,i) = v'*E*[cos(fi(i)); -sin(fi(i))];
end
op = 1.5*max(max(pH));

figure(1)
fill(pH(1,:), pH(2,:), 'c')
hold on
plot([0, L(1)*v(1,1)], [0, L(1)*v(1,2)], ':r')
plot([0, L(2)*v(2,1)], [0, L(2)*v(2,2)], ':r')
for i = 1:n
    plot(X(i,1), X(i,2), '*b')
end
axis([-op op -op op])
axis square
az = axis;
plot([az(1) az(2)], [0 0], ':k')
plot([0 0], [az(3) az(4)], ':k')
set(gca, 'FontName','Arial', 'FontSize',12)
xlabel('x_1')
ylabel('x_2')

end