function [S,E]=PCA_ellipse(Z)
% 
% Environmental Systems Analysis with Matlab 
% S. Marsili-Libelli
%
%  CRC Press 2016
% ISBN 9781498706353
% Matlab code revised by Emanuele El Basri and Giacomo Barni
% *************************************************************************
% 
% This function draws the ellipse related to the provided matrix Z and
% returns the PCA and the eigenvalues matrices.
% Z must be 2x2.
%
% *************************************************************************
% 
%      [S, E] = PCA_ELLIPSE(Z)
% 
%    Input:
%           Z      Matrix of the input data. Must be 2x2.
% 
%    Output:
%           S      Matrix of the principal components of Z.
%
%           E      Eigenvalues of Z ordered from the largest to the
%                  smallest.
%

%% Compute the PCA and the eigenvalues of Z
[E, I] = sort(eig(Z), 'descend'); % Eigenvalues ordered largest first
[v, e] = eig(Z)
S = v(:, I); % PCA Matrix (by columns)

L1 = sqrt(1/E(1));
L2 = sqrt(1/E(2));
F = diag(L1, L2);
fi = [0:0.001:2*pi];
pH = ones(2,length(fi));
for i = 1:length(fi);
    pH(:,i) = S'*F*[cos(fi(i)); -sin(fi(i))];
end

%% Figures
figure(1)
plot(pH(1,:), pH(2,:), 'b')
axis square
set(gca, 'FontName','Arial', 'FontSize',12)
xlabel('x_1'),ylabel('x_2')
hold on
az = axis;
plot([az(1) az(2)],[0 0], ':k')
plot([0 0], [az(3) az(4)], ':k')

plot([0,L1*v(1,1)], [0,L1*v(1,2)], ':r')
plot([0,L2*v(2,1)], [0,L2*v(2,2)], ':r')

end