function Residual_analysis(x,fig_num)
% Statistical analysis of data
% computationof the following quantities
%   o  Residual autocorrelation
%   o  Residual distribution
%   o  Residual test for gaussianity
%      with K-S and Lilliefors tests
%
% SML 2012
Delay=floor(length(x)/5);
% Compute residual autocorrelation
autocorr(x,Delay,fig_num);

% Histogram
figure(fig_num+1)
set(fig_num+1,'Position',[545 55 509 316])
subplot(121)
Nbin=23;
[hy,hx]=hist(x,Nbin);
hy=hy/sum(hy);  %Frequency normalization
dx=diff(hx);
dx=dx(1);
hy=hy/dx;
bar(hx,hy)
hold on
% Fit a gaussian distribution to the residuals x
[mu,sig,muci,sigci]=normfit(x);
% estimate the normal pdf for the bin centres
hxx=[min(x) hx max(x)];
yfit=normpdf(hxx,mu,sig);
yc=normcdf(hxx,mu,sig);
plot(hxx,yfit,'-.r','LineWidth',2)
set(gca,'FontName','Arial','FontSize',10)
axis tight
hold on
xlabel('Residuals')
ylabel('Rel. freq.')
legend('hist.','fitted pdf','location','northoutside','orientation','horizontal')

% Cumulative distributions
subplot(122)

hyc=cumsum(hy);
hcm=max(hyc);
hyc=hyc/hcm;
stairs(hx,hyc)
hold on
plot(hxx,yc,'-.r','LineWidth',2)
CF=[hxx; yc]';
xlabel('Residuals')
ylabel('Cum. Distr.')
legend('exp. cdf','fitted cdf','location','northoutside','orientation','horizontal')
% Kolmogorov-Smirnov test for gaussianity
alfa=0.05;
h_KS = kstest(x,CF,alfa);
disp('-----------------------------------------------')
disp(['Kolmogorov - Smirnov Test: ',num2str(h_KS)])
if h_KS==1,disp(['Normality hypothesis rejected at ',num2str(100*(1-alfa)),'%']),end
if h_KS==0,disp(['Normality hypothesis accepted at ',num2str(100*(1-alfa)),'%']),end
disp('  ')
% Lillietest test for gaussianity
h_L=lillietest(x,alfa);
disp(['Lilliefors Test:  ',num2str(h_L)])
if h_L==1,disp(['Normality hypothesis rejected at ',num2str(100*(1-alfa)),'%']),end
if h_L==0,disp(['Normality hypothesis accepted at ',num2str(100*(1-alfa)),'%']),end
disp('-----------------------------------------------')