function maxdef = idmsize(N, d)
%
% Environmental Systems Analysis with Matlab
% S. Marsili-Libelli
%
%  CRC Press 2016
% ISBN 9781498706353
% Matlab code revised by Emanuele El Basri and Giacomo Barni
% *************************************************************************
%
% Sets default value for the variable MAXSIZE OF COVF (see help AUXVAR).
%
% The value of MAXDEF that gives the most efficient computing time
% in the parameter estimation algorithms depends on the memory available
% in the computer.
% The algorithms will work with matrices that are N-by-D, provided the
% number of elements is less than MAXSIZE. Note that the number D is
% not provided by all of the estimation algorithms.
% USERS WHO WORK WITH VERY LARGE DATA RECORDS AND LARGE MODELS SHOULD
% TRIM THIS ALGORITHM TO HIS OR HER COMPUTER
%
% L. Ljung 10-1-89
% Copyright (c) 1986-98 by The MathWorks, Inc.
% $Revision: 2.3 $  $Date: 1997/12/02 03:42:22 $
%
% *************************************************************************
%

if nargin < 2
    d = 6;
end
if nargin < 1,
    N = 1000;
end

[cmp, mem] = computer;
if mem < 8192
    maxdef = 4096;
else
    maxdef = 50000;
end

end