function [bin, freq, cum_p, p_norm, R_m, R_std] = istg(series, g)
%
% Environmental Systems Analysis with Matlab
% S. Marsili-Libelli
%
%  CRC Press 2016
% ISBN 9781498706353
% Matlab code revised by Emanuele El Basri and Giacomo Barni
% *************************************************************************
%
% This function plots the histogram of the provided vector SERIES dividing
% the data in G intervals
%
% *************************************************************************
%
%      [BIN, FREQ, CUM_P, P_NORM, R_M, R_STD] = ISTG(SERIES, G)
%
%    Input:
%           SERIES   Vector of the time-series data.
%
%           G        Number of equally spaced containers.
%
%    Output:
%           BIN      Vector of the G equally spaced containers positions.
%
%           FREQ     Vector of the frequencies.
%
%           CUM_P    Cumulative of the probability distribution.
%
%           P_NORM   Normalized area of the PDF.
%
%           R_M      Mean estimation of the data.
%
%           R_STD    Standard deviation estimation of the data.
%

%% Histogram of steady-states averages

n = length(series);
order = sort(series);
a = order(1);
b = order(n);
pace = (b - a)/g;
Inter = [a:pace:b];
w = length(Inter);
for d = 2:1:w
    bin(d - 1) = (Inter(d) + Inter(d-1))/2;
end
for k = 2:1:g+1
    x = 0;
    for h = 1:1:n
        if (order(h) < Inter(k))&& (order(h) >= Inter(k-1))
            x = x+1;
        else
            x = x;
        end
    end
    nums(k-1) = x;
end
nums(g) = nums(g) + 1;
freq = (nums')/n;
% Figure
hold off
bar(bin, freq');
hold on

%% Gaussian pdf fitting
%  Mean and Std. dev. extimation from data
R_m = mean(series);
R_std = std(series);

p = normpdf(bin, R_m, R_std);
cum_p = cumsum(p);

% Area normalisation
p_norm = max(cum_p);
plot(bin, p/p_norm, 'r');
plot(bin, p/p_norm, 'or');
xlabel('Residuals')
ylabel('Rel. freq.')
title('Residual histogram and Gaussian PDF fitting')
end