function index = outlier(y, crit )
%
% Environmental Systems Analysis with Matlab
% S. Marsili-Libelli
%
%  CRC Press 2016
% ISBN 9781498706353
% Matlab code revised by Emanuele El Basri and Giacomo Barni
% *************************************************************************
%
% Detection and Removal of Outliers in Data Sets 
% (Rosner's many-outlier test).
%
% Bob Newell, February 1996
% revised by Stefano Marsili-Libelli, December 2004
%
% *************************************************************************
%
%      INDEX = OUTLIER(Y, CRIT)
%
%    Input:
%           Y        Data set (should be stationary).
%
%           CRIT     Detection criterion (default 2).
%
%    Output:
%           INDEX    Indices of outliers in the data.
%

y = y(:);
n = length( y );
k = 10;
if nargin > 1
    lambda = crit;
else
    lambda = 2;
end
R = zeros(k+1, 1);

% Sort deviations from the mean
ybar = mean(y);
[ys, is] = sort(abs(y - ybar));

% Calculate statistics for up to k outliers
for i = 0:k
    yy = ys(1:n-i);
    R(i+1) = abs(yy(n-i) - mean(yy))/std(yy);
end

% Statistical test to find outliers
index = [];
for i = 1:k
    if R(i)/R(k+1) > lambda
        index = [index is(n-i+1)];
    end
end

% Report results
disp(['Outliers detected = ', num2str(length(index ))])
if length(index ) > 0
    disp('Outlier indices are:')
    index = sort(index);
	disp(index)
end

end