function [q_out, hq1, hq4] = percentiles(q, Q_low, Q_hi)
% 
% Environmental Systems Analysis with Matlab 
% S. Marsili-Libelli
%
%  CRC Press 2016
% ISBN 9781498706353
% Matlab code revised by Emanuele El Basri and Giacomo Barni
% *************************************************************************
% 
% Plot the quartiles Q1 and Q4.
%
% *************************************************************************
% 
%      [Q_OUT HQ1, HQ4] = PERCENTILES(Q, Q_LOW, Q_HI)
% 
%    Input:
%           Q        Vector of the data.
%
%           Q_LOW    The lower quantile (Q_low = 0.1).
%
%           Q_HI     The upper quantile (Q_hi = 0.9).
% 
%    Output:
%           Q_OUT    Vector of the outlying data (below Q_low or 
%                    above Q_hi).
%
%           HQ1      The lower percentile.
%
%           HQ4      The upper percentile.
%

Nbin = 30;
[hy, hx] = hist(q, Nbin);
hy = hy/sum(hy);  % Frequency normalization
dx = diff(hx);
dx = dx(1);
hy = hy/dx;
hyc = cumsum(hy);
hcm = max(hyc);
hyc = hyc/hcm;
stairs(hx, hyc, '--b', 'LineWidth',2)
% set(gca, 'FontName','Arial', 'FontSize',12) % If commented the font style
                                              % is inherited from the 
                                              % calling script
hold on

%% Lower percentile
hq = find(hyc > Q_low);
hq1 = hx(hq(1));

%% Upper percentile
hq = find(hyc > Q_hi);
hq4 = hx(hq(1));

IQ = find((hx >= hq1) & (hx <= hq4));
stairs(hx(IQ), hyc(IQ), 'r', 'LineWidth',3)
a = axis;
a(1) = min(q);
a(2) = max(q);
plot([hq1 hq1], [0 Q_low], ':r', 'LineWidth',2)
plot([a(1) hq1], [Q_low Q_low], ':r', 'LineWidth',2)
plot([hq4 hq4], [0 Q_hi], ':r', 'LineWidth',2)
plot([a(1) hq4], [Q_hi Q_hi], ':r', 'LineWidth',2)
xlabel('Data range')
ylabel('Cum. Distr.')
axis tight

%% Find the outlying data
q_out = find((q <= hq1)|(q >= hq4));