function bspc = scree(B, fig)
% 
% Environmental Systems Analysis with Matlab 
% S. Marsili-Libelli
%
%  CRC Press 2016
% ISBN 9781498706353
% Matlab code revised by Emanuele El Basri and Giacomo Barni
% *************************************************************************
% 
% This function creates the scree plot from eigenvalues B.
%
% *************************************************************************
% 
%      BSPC = SCREE(B, FIG)
% 
%    Input:
%           B        Vector of the eigenvalues.
%
%           FIG      Number of the figure.
% 
%    Output:
%           BSPC     Cumulative explained variance percentage.
%

figure(fig)
clf
subplot(211)
%% Compute the percentage variance for each eigenvalue
bar(B/sum(B));
hold on

%% Compute the cumulative explained variance 
bs = cumsum(B/sum(B));
bspc = 100*bs;

plot(bs, 'o-b')
xlabel('PC n')
ylabel('Perc. Variance')
legend('Perc. var. expl.', 'Cum. var. expl.',...
       'location','northoutside', 'orientation','horizontal')
axis([0.5 length(bs)+0.5 0 1])

subplot(212)
plot(B, '-db')
hold on
az = axis;
plot([az(1) az(2)], [0.7 0.7], ':k')
set(gca, 'XTick', [1:length(bs)])
ylabel('Eigenvalues')
xlabel('PC n')
end