function Xs = standardize(X)
% 
% Environmental Systems Analysis with Matlab 
% S. Marsili-Libelli
%
%  CRC Press 2016
% ISBN 9781498706353
% Matlab code revised by Emanuele El Basri and Giacomo Barni
% *************************************************************************
% 
% This function returns the standardized version of the input matrix X.
% Each column of the standardized XS will contain the centered and scaled
%  values of the corresponding column of X i.e. the values have the mean  
% subtracted and are divided by the standard deviation so that each column
% of XS has zero mean and unit variance.
%
% *************************************************************************
% 
%      XS = STANDARDIZE(X)
% 
%    Input:
%           X      N-by-P matrix of the unscaled input data. Each row
%                  represents an observation and each column a variable.
% 
%    Output:
%           XS     N-by-P matrix of the standardized values of X.
%

[n p] = size(X);

Xs = zeros(n, p);
for i = 1:p
    m = mean(X(:,i));
    sigma = std(X(:,i));
    Xs(:,i) = (X(:,i) -m)./sigma;
end

end