% *************************************************************************
% 
% Environmental Systems Analysis with Matlab 
% S. Marsili-Libelli
%
%  CRC Press 2016
% ISBN 9781498706353
% Matlab code revised by Emanuele El Basri and Giacomo Barni
% *************************************************************************
%
% This exercise demonstrates the ANFIS approach to the Tank modelling with 
% a Simulink second-order model using the previously calibrated ANFIS Logic.
%
% Sect. 4.4.3.c
%
% *************************************************************************

clear
close all
clc 

%% Load data
load CSTR_data     % Input Flow data

Kv = 2.6;          % Output valve time constant
A  = 50;           % Tank cross-section
ho = 1.6;          % Initial heigth
tfin = t_dot(end); % Simulation length
Fo = F_dot(1);
ho = 1.5;
Ts = diff(t_dot);
Ts = Ts(1);

%% Read ANFIS model from disk
Tank = readfis('CSTR4_Sug2'); % Assign it to the Simulink fuzzy controller block

%% Simulation
tic
[t, x, y] = sim('CSTR4_fuzzy_Sugeno', tfin);
toc

%% Figure
figure(1)
set(1, 'Position',[24 42 887 498])
hold off
clf
td = 0:2*Ts:tfin;
hd = interp1(t, h, td);
hf = interp1(t_dot, h_fuz, td);
plot(td, hd, 'ob', 'MarkerFaceColor','b')
hold on
plot(td, hf, 'b')
set(gca, 'FontName','Arial', 'FontSize',14)
xlabel('time [min]')
ylabel('h [m]')
legend('Real h', 'ANFIS h', 'location','northoutside',...
       'orientation','horizontal')