% *************************************************************************
%
% Environmental Systems Analysis with Matlab
% S. Marsili-Libelli
%
%  CRC Press 2016
% ISBN 9781498706353
% Matlab code revised by Emanuele El Basri and Giacomo Barni
% *************************************************************************
%
% This exercise demonstrates the FCM Algorithm
% (Bezdek, 1981)
% as described in sect. 4.5.2
%
% Input parameters:
%
%    m      = fuzzy exponent
%    X      = data matrix (Nxp)
%    c      = number of clusters
%    epss   = threshod value to terminate the iteration
%    it_max = maximum number of iterations
%
% Output parameters
%    U      = membership matrix
%    V      = centroid matrix
%
% *************************************************************************

clear
close all
clc

%% Data input
disp('------------------------------------------')
disp('-------- Fuzzy C-MEANS Clustering --------')
disp('------------------------------------------')
disp(' ')
F_I = input('Do you want to load data from a file (1) or by direct input (2)? ');
if F_I == 1 % Get the data from file
    g = uigetfile('X*.mat', 'Load data');
    eval(['load ' g]);
    figure(1) % Plot the data
    set(1, 'Position',[29 45 593 526])
    xmin = 0;
    xmax = 1;
    ymin = 0;
    ymax = 1;
    axis([xmin xmax ymin ymax])
    axis square
    axis(axis)
    set(gca, 'FontName','Arial', 'FontSize',14)
    xlabel('x_1')
    ylabel('x_2')
    hold on
    N = size(X,1);
    for i = 1:N
        plot(X(i,1), X(i,2), 'ok', 'MarkerSize',7,...
             'MarkerFaceColor',[0.83 0.82 0.78])
    end
else if F_I == 2,  % Enter data with the mouse
        figure(1)
        TTL = title('Right-click to exit data entry');
        set(1, 'Position',[29 45 593 526])
        xmin = 0;
        xmax = 1;
        ymin = 0;
        ymax = 1;
        axis([xmin xmax ymin ymax])
        axis square
        axis(axis)
        set(gca, 'FontName','Arial', 'FontSize',14)
        xlabel('x_1')
        ylabel('x_2')
        hold on
        X = [];
        i = 0;
        butt = 1;
        while butt == 1
            i = i + 1;
            [x, y, butt] = ginput(1);
            plot(x, y, 'ok', 'MarkerSize',7,...
                 'MarkerFaceColor', [0.83 0.82 0.78])
            X = [X; x y];
        end
        delete(TTL); clear TTL
        sf = input('Do you want to save the data? (y/n) ', 's');
        if sf == 'y' % Save the data for later
            Fname = input('Name of data file ', 's');
            Fn = char(Fname);
            eval(['save ', Fn, ' X'])
        end
    end
end

%% Data dimension
[n p] = size(X);

%% Inputting cluster characteristics
m = input('Fuzzy exponent: ');
c = input('Number of clusters: ');

%% Start the main FCM function
[U, V] = FCM(X, m, c);
%[Xs Ind]=sort(X(:,1));

%% Compute the fuzzy entropy
Hn = Fuzzy_entropy(U);

%% Compute the separation coefficient
[g, r] = Sep_Coef(X, U, V);

figure(1)
plot(V(:,1), V(:,2), 'sk', 'MarkerFaceColor','k', 'MarkerSize',10)
title(['H_n = ', num2str(Hn), ' ', 'g = ', num2str(g)])
Xrange = [xmin xmax];
Yrange = [ymin ymax];

%% Trace the constant-membership loci
plot_memb(Xrange, Yrange, V, m)