function Unew = classif(X, V, m)
%
% Environmental Systems Analysis with Matlab
% S. Marsili-Libelli
%
%  CRC Press 2016
% ISBN 9781498706353
% Matlab code revised by Emanuele El Basri and Giacomo Barni
% *************************************************************************
%
% This function classifies the new data with respect to a partition
% previously induced by FCM clustering.
%
% *************************************************************************
%
%      UNEW = CLASSIF(X, V, M)
%
%    Input:
%           X        N-by-P matrix of the N data of P features to be
%                    classified.
%
%           V        C-by-P matrix containing the C centroids of the
%                    clusters.
%
%           M        Fuzziness parameter of the partition used.
%
%    Output:
%           UNEW     C-by-N partition matrix of data X with respect to the
%                    clusters provided by V.
%

toll = 1e-7;           % Tolerance with which a centroid and an observation
toll = toll^(2/(m-1)); % are considered coincident.

[n, p] = size(X);
[c, p] = size(V);

%% Compute the matrix of distances D2
for k=1:n
    for i=1:c
        D2(i,k)=(norm((V(i,:)-X(k,:)),2))^(2/(m-1));
    end;
end;

%% Compute the partition matrix Unew
Unew = zeros(c,n);
for k = 1:n
    ind = 0;
    for i = 1:c            % Ik contains the indexes of the centroids that
        if D2(i,k) < toll  % coincide less than TOLL with the k-th obs.
            ind = ind + 1; % If there are any the vector is not created.
            Ik(ind) = i;
        end
    end                    % If IND = 0 it means that no centroid coincides
    if ind == 0            % with the k-th observation.
        aux = ones(1,c)*(ones(c,1)./D2(:,k));
        Unew(:,k) = ones(c,1)./(D2(:,k)*aux);
    else
        Unew(Ik,k) = ones(ind,1)/ind;
    end
    clear Ik;
end

end