function plot_memb(X, Y, V, m)
%
% Environmental Systems Analysis with Matlab
% S. Marsili-Libelli
%
%  CRC Press 2016
% ISBN 9781498706353
% Matlab code revised by Emanuele El Basri and Giacomo Barni
% *************************************************************************
%
% This function is used to trace the constant-membership loci.
%
% *************************************************************************
%
%      PLOT_MEMB(X, Y, V, M)
%
%    Input:
%           X        Contains the minimum and maximum values of the x
%                    domain.
%
%           Y        Contains the minimum and maximum values of the y
%                    domain.
%
%           V        Is the centroid matrix.
%
%           M        Is the fuzzy exponent.
%

[c n] = size(V);
xmin = X(1);
xmax = X(2);
ymin = Y(1);
ymax = Y(2);
dx = (xmax - xmin)/50;
dy = (ymax - ymin)/50;
U = [];

for x1 = xmin:dx:xmax;
    for x2 = ymin:dy:ymax;
        u = classif([x1 x2], V, m);
        U = [U u];
    end
end

figure(1)
X = [xmin:dx:xmax];
Y = [ymin:dy:ymax];
nx = length(X);
ny = length(Y);

for i = 1:c
    Ui = reshape(U(i,:), nx, ny);
    [C, h]=contour(X, Y, Ui, [0.5 0.75 0.9], ':k');
    set(h, 'ShowText', 'on')
end

end