function GK_Alfa_contour(X, Y, V, m, P)
%
% Environmental Systems Analysis with Matlab
% S. Marsili-Libelli
%
%  CRC Press 2016
% ISBN 9781498706353
% Matlab code revised by Emanuele El Basri and Giacomo Barni
% *************************************************************************
%
% Explanation of the code function goes here
%
% *************************************************************************
%
%      GK_ALFA_CONTOUR(X, Y, V, M, P)
%
%    Input:
%           X      Contains the minimum and maximum values of the x domain.
%
%           Y      Contains the minimum and maximum values of the y domain.
%
%           V      Is the centroid matrix.
%
%           M      Is the fuzzy exponent.
%
%           P      Is the Fuzzy Covariance Matrix (aggregated).
%

[c, n] = size(V);
xmin = X(:,1);
xmax = X(:,2);
ymin = Y(:,1);
ymax = Y(:,2);
dx = (xmax - xmin)/50;
dy = (ymax - ymin)/50;
U = [];
for x1 = xmin:dx:xmax;
    for x2 = ymin:dy:ymax;
        u = fgrade([x1 x2], V, m, P);
        U = [U; u];
    end
end
U = U';
Xp = [xmin:dx:xmax];
Yp = [ymin:dy:ymax];
nx = length(Xp);
ny = length(Yp);
axis([xmin xmax ymin ymax])
for i=1:c
    Ui = reshape(U(i,:),nx,ny);
    [C, h]= contour(Xp, Yp, Ui, [0.5 0.75 0.9], ':k');
    set(h, 'ShowText', 'on')
end

end