function [G, r] =  Sep_Coef(X, U, V)
%
% Environmental Systems Analysis with Matlab
% S. Marsili-Libelli
%
%  CRC Press 2016
% ISBN 9781498706353
% Matlab code revised by Emanuele El Basri and Giacomo Barni
% *************************************************************************
%
% Computation of the separation coefficient.
%
% *************************************************************************
%
%      [G, R] = SEP_COEF(X, U, V)
%
%    Input:
%           X        N-by-P matrix of the N data of P features to be
%                    classified.
%
%           U        C-by-N partition matrix of data X with respect to the
%                    clusters provided by V.
%
%           V        C-by-P matrix containing the C centroids of the
%                    clusters.
%
%    Output:
%           G        Separation coefficient:
%                     - G < 1 the clusters are well separated;
%                     - G = 1 the clusters are tangent;
%                     - G > 1 the clusters are intersecting.
%
%           R        Maximum distance among clusters.
%

[n p] = size(X);
[c q] = size(V);

%% Computation fo the distance matrix D2
for k = 1:n
    for i = 1:c
        D2(i,k) = (norm((V(i,:) - X(k,:)),2));
    end
end
R = U.*D2; % Weight distances with membership

r = max(R'); % Maximum inter-cluster distance
%% Distance among clusters
for k = 1:c
    for i = 1:c
        DV(i,k) = (norm((V(i,:) - V(k,:)),2));
    end;
end;
%% Intra and inter cluster distances ratios
g = [];
for i = 1:c
    for j = i+1:c
        g = [g (r(i)+r(j))/DV(i,j)];
    end
end
G = max(g); % Separation coefficient
if G < 1
    fprintf(['Well separated clusters  g = ',num2str(G),'\n'])
end
if G == 1
    fprintf(['Tangent clusters','\n'])
end
if G > 1
    fprintf(['Intersecting clusters  g = ',num2str(G),'\n'])
end

end