function FHV = fhyperv(x, f, c, m)
%
% Environmental Systems Analysis with Matlab
% S. Marsili-Libelli
%
%  CRC Press 2016
% ISBN 9781498706353
% Matlab code revised by Emanuele El Basri and Giacomo Barni
% *************************************************************************
%
% FHYPERV computes fuzzy hypervolume for a given fuzzy partition
% obtained with the GK algorithm.
%
% (c) Robert Babuska, 1993-95
%
% *************************************************************************
%
%      FHV = FHYPERV(X, F, C, M)
%
%    Input:
%           X      Data matrix.
%
%           F      Fuzzy partition matrix.
%
%           C      Cluster center (means) matrix .
%
%           M      Fuzziness parameter.
%
%    Output:
%           FHV    Fuzzy hypervolume.
%

[NC, nx] = size(c);
P = fcov(x, f, c, m);
for j = NC : -1 : 1,
    detP(j) = det(P((j-1)*nx+(1:nx),:));
end
FHV = sum(sqrt(detP));

end