function fuzzy_contour(Z,d1,d2,f,v,c,m,P,method,rho,Ex)
%
% Environmental Systems Analysis with Matlab
% S. Marsili-Libelli
%
%  CRC Press 2016
% ISBN 9781498706353
% Matlab code revised by Emanuele El Basri and Giacomo Barni
% *************************************************************************
%
% Uses fgrades.m to calculate membership grades.
%
% Modified with adaptive cluster volumes
% Stefano Marsili-Libelli and Matteo Masi (March 2011)
%
% *************************************************************************
%
%      fuzzy_contour(Z,d1,d2,f,v,c,m,P,method,rho,Ex)
%
%    Input:
%           Z        data set.
%
%           d1, d2   plotting dimensions. d1 first component to plot, d2
%                    second component to plot.
%
%           f        fuzzy partition matrix.
%
%           v        centroid matrix.
%
%           c        number of clusters.
%
%           P        fuzzy exponent.
%
%           method   clustering method 'GK' or 'FMLE' (default 'GK').
%
%           IN2      Description of the second input variable here.
%
%           IN2      Description of the second input variable here.
%
%           IN2      Description of the second input variable here.
%

if nargin < 9
    method = 'GK';
end
if nargin < 10
    rho = ones(1,c);
end

if nargin < 11
    n_data = size(Z,1);
    plot(Z(:,d1), Z(:,d2), '.b')
    hold on
    Ex = axis;
    for j = 1:c
        plot(v(j,d1), v(j,d2), 'sk', 'MarkerFaceColor','k', 'MarkerSize',10)
    end
end

xmin = Ex(1);
xmax = Ex(2);
ymin = Ex(3);
ymax = Ex(4);
dx = (xmax - xmin)/50;
dy = (ymax - ymin)/50;
U_clas = [];
Uc = [];
for x1 = xmin:dx:xmax;
    for x2 = ymin:dy:ymax;
        X = [x1 x2];
        [U_clas, dd] = fgrades(X, v, m, P, method, f,rho); %% !
        %       [f,dd] = fgrades(x,v,p,P,method,f_fmle,rho)
        Uc = [Uc; U_clas];
    end
end

Xd = [xmin:dx:xmax];
Yd = [ymin:dy:ymax];
nx = length(Xd);
ny = length(Yd);
for j = 1:c
    Uj = reshape(Uc(:,j), nx, ny);
    [C, h] = contour(Xd, Yd, Uj, [0.5 0.75 0.9], ':k');
    set(h, 'ShowText', 'on')
end

end