function Alfa_contour_PCM(X, V, ETA, m)
%
% Environmental Systems Analysis with Matlab
% S. Marsili-Libelli
%
%  CRC Press 2016
% ISBN 9781498706353
% Matlab code revised by Emanuele El Basri and Giacomo Barni
% *************************************************************************
%
% Trace constant membership loci.
%
% *************************************************************************
%
%      ALFA_CONTOUR(X, V, ETA, M)
%
%    Input:
%           X        Contains the minimum and maximum values of the x
%                    domain.
%
%           V        Is the centroid matrix.
%
%           ETA      .
%
%           M        Is the fuzzy exponent.
%

[c n] = size(V);
xmin = min(X(:,1));
xmax = max(X(:,1));
ymin = min(X(:,2));
ymax = max(X(:,2));
dx = (xmax - xmin)/50;
dy = (ymax - ymin)/50;
U = [];
for x1 = xmin:dx:xmax;
    for x2 = ymin:dy:ymax;
        u = Classif_PCM([x1 x2], V, ETA, m);
        U = [U, u];
    end
end

X = [xmin:dx:xmax];
Y = [ymin:dy:ymax];
nx = length(X);
ny = length(Y);

figure(1)
for i = 1:c
    Ui = reshape(U(i,:), nx, ny);
    [C, h] = contour(X, Y, Ui, [0.05 0.2 0.5 0.75 0.9], ':k');
    set(h, 'ShowText','on')
end

end