function Unew = Classif_PCM(X, V, ETA, m)
%
% Environmental Systems Analysis with Matlab
% S. Marsili-Libelli
%
%  CRC Press 2016
% ISBN 9781498706353
% Matlab code revised by Emanuele El Basri and Giacomo Barni
% *************************************************************************
%
% This function classifies new data with respect to a partition previously
% introduced by the FCM clustering.
%
% *************************************************************************
%
%      Unew = Classif_PCM(X, V, ETA, m)
%
%    Input:
%           X        n-by-p matrix containing the n observations of the p
%                    features to be classified.
%
%           V        c-by-p matrix containing the c centroids.
%
%           ETA      .
%
%           m        Fuzzy exponent.
%
%    Output:
%           Unew     c-by-n partition matrix of the data X with respect to 
%                    the centroids of V.
%

toll = 1e-7;           % Tolerance of coincident centroids
toll = toll^(2/(m-1));

[n, p] = size(X);
[c, p] = size(V);

%% Computation of the distance matrix D2
for k = 1:n
    for i = 1:c
        D2(i,k)=(norm((V(i,:)-X(k,:)),2))^(2/(m-1));
    end;
end;

%% Computation of the partition matrix Unew
Unew=zeros(c,n);
for k=1:n;
    for i=1:c;
        Unew(i,k)= 1/(1+(((D2(i,k)^(1/2))/ETA(i))^(2/(m-1))));
    end
end

end