%**************************************************************************
%
% Environmental Systems Analysis with Matlab
% S. Marsili-Libelli
%
%  CRC Press 2016
% ISBN 9781498706353
% Matlab code revised by Emanuele El Basri and Giacomo Barni
% *************************************************************************
%
% This exercise demonstrates the Possibilistic Clustering algorithm (PCM)
% based on Bezdek's FCM.
%
% Sect. 4.5.10
%
% *************************************************************************

clear
close all
clc

%% Data input
disp('------------------------------------------')
disp('-------- Possibilistic Clustering --------')
disp('------------------------------------------')
disp(' ')
F_I = input('Do you want to load data from a file (1) or by direct input (2)? ');
if F_I == 1
    % Get the data from file
    g = uigetfile('PCM*.mat', 'Load data');
    eval(['load ' g]);
    
    % Plot the data
    figure(1)
    set(1, 'Position',[29 45 593 526])
    axis square
    hold on
    N = size(X,1);
    x1min = floor(min(X(:,1)));
    x1max = ceil(max(X(:,1)));
    x2min = floor(min(X(:,2)));
    x2max = ceil(max(X(:,2)));
    Ex = [x1min x1max x2min x2max];
    axis(Ex);
    set(gca, 'FontName','Arial', 'FontSize',12)
    for i = 1:N
        plot(X(i,1) ,X(i,2), 'ok', 'MarkerSize',7,...
            'MarkerFaceColor',[0.83 0.82 0.78])
    end
    Xlim = [x1min x1max];
    Ylim = [x2min x2max];
else
    if F_I == 2,
        % Enter data with the mouse
        figure(1)
        set(1, 'Position',[29 45 593 526])
        set(gca, 'FontName','Arial', 'FontSize',12)
        x1min = 0;
        x1max = 1;
        x2min = 0;
        x2max = 1;
        axis([x1min x1max x2min x2max])
        Xlim = [x1min x1max];
        Ylim = [x2min x2max];
        axis square
        axis(axis)
        hold on
        X = [];
        i = 0;
        butt = 1;
        TTL = title('Right-click to exit data entry');
        while butt == 1
            i = i + 1;
            [x, y, butt] = ginput(1);
            plot(x, y, 'ok', 'MarkerSize',7,...
                'MarkerFaceColor',[0.83 0.82 0.78])
            X = [X; x y];
        end
        delete(TTL); clear TTL
        
        % Save the data
        Save_data = input('Do you want to save your data? (y/n) ','s');
        if Save_data == 'y',
            Fname = input('Name of data file ','s');
            Fn = char(['PCM_', Fname]);
            Mn = 'X';
            eval(['save ',Fn,' ', Mn])
        end
    end
end
%
m = input('Fuzzy exponent: ');
c = input('Number of clusters: ');
[U, V, ETA] = PCM(X, m, c);
figure(1)
plot(V(:,1),  V(:,2), 'sk','MarkerFaceColor','k', 'MarkerSize',10)

%% Trace constant membership loci.
Alfa_contour_PCM(X, V, ETA, m)