function [U, V, ETA] = PCM(X, m, c)
%
% Environmental Systems Analysis with Matlab
% S. Marsili-Libelli
%
%  CRC Press 2016
% ISBN 9781498706353
% Matlab code revised by Emanuele El Basri and Giacomo Barni
% *************************************************************************
%
% Possibilistic Clustering.
%
% *************************************************************************
%
%      [U, V, ETA] = PCM(X, m, c)
%
%    Input:
%           X        Matrix of the observations.
%
%           m        Fuzziness parameter.
%
%           c        Number of clusters.
%
%    Output:
%           U        Membership matrix.
%
%           V        Centroids matrix.
%
%           ETA      Description of the second output variable here.
%

epss = 10e-4;
it_max = 100;
toll = 1e-7;
toll = toll^(2/(m-1));
[n, p] = size(X);

%% Initialize FCM
norma = 10; % norm
loop = 0;
code = 1;
[U, V, D2] = FC_means(X, m, c);
Unew = U;
D = D2;

%% Compute ETA
E = zeros(c, n);
for i = 1:c;
    for k = 1:n;
        E(i, k) = (((Unew(i, k))^m)*(D(i, k)));
    end
end
for i = 1:c;
    num(i) = sum(E(i,:));
    den(i) = sum((Unew(i,:)).^m);
    ETA(i) = num(i)/den(i);
end

%% Iterative cycle
while norma > epss && loop <= it_max
    U = Unew;
    loop = loop + 1;
    
    % Computation ov the centroids matrix V
    Um = U.^m;
    S = Um*X;
    Den = Um*ones(n,1);
    for i = 1:c;
        V(i,:) = S(i,:)/Den(i);
    end
    
    % Compute the distances D2
    for k = 1:n;
        for i = 1:c;
            D_quad(i, k) = (norm((V(i,:)-X(k,:)),2))^(2/(m-1));
        end
    end
    
    % Update the partition matix U
    Unew = zeros(c, n);
    for k = 1:n;
        for i = 1:c;
            Unew(i, k) = 1/(1+(((D_quad(i,k)^(1/2))/ETA(i))^(2/(m-1))));
        end
    end
    norma = max(max(abs(Unew - U)));
end

%% Verify that diff U is less than epsilon
if norma < epss;
    code = 0;
end

end