% *************************************************************************
%
% Environmental Systems Analysis with Matlab
% S. Marsili-Libelli
%
%  CRC Press 2016
% ISBN 9781498706353
% Matlab code revised by Emanuele El Basri and Giacomo Barni
% *************************************************************************
%
% Empirical fuzzy flow model using Mamdani or Sugeno FIS with heuristic
% rules definition.
%
% Sect. 4.4.2
%
% *************************************************************************

clear
close all
clc

load IN_data  % Input Flow data

Kv = 2.6;  % Output valve time constant
A  = 50;   % Tank cross-section
ho = 2.4;  % Initial heigth
Ts = 20;
tfin = 600;

%% Fuzzy Logic selection
Model_Flag = 1;
if Model_Flag == 1, % Mamdani Model
    Tank_M = readfis('Tank_M');
    [t,x,y] = sim('CSTR_fuzzy_Mamdani', tfin);
else              % Sugeno Model
    Tank_S = readfis('Tank_S');
    [t,x,y] = sim('CSTR_fuzzy_Sugeno', tfin);
end

%% Figure
figure(1)
set(1,'Position',[17 58 560 420])
plot(t,f,'r', t,h,'b')
hold on
plot(t_d, h_fuz, '*:m')
legend('Input flow', 'Observed h', 'Fuzzy model h',...
    'location','northoutside', 'orientation','horizontal')
t_dot = 0:20:tfin;
F_dot = interp1(t, f, t_dot,'spline');
plot(t_dot, F_dot, 'or','MarkerFaceColor','r')
hold on
h_dot = interp1(t, h, t_dot, 'spline');
plot(t_dot, h_dot, 'ob')
xlabel('time [min]')