% *************************************************************************
% 
% Environmental Systems Analysis with Matlab 
% S. Marsili-Libelli
%
%  CRC Press 2016
% ISBN 9781498706353
% Matlab code revised by Emanuele El Basri and Giacomo Barni
% *************************************************************************
%
% Demonstration of the invulnerability region for two competing populations
% using the Lyapounov principle.
% 
% Sect. 5.4.4.1 
%
% *************************************************************************

clear
close all
clc

r1     = 22;
r2     = -5;
g11    = 0.1;
g12    = 2.1;
g21    = -0.7;
g22    = 0.2;
sigma  = 5;
u_lim  = 100;
tfin   = 5;
Prey_o = 10;
Pred_o = 16;

%% Run simulation
[t,x,y] = sim('Lyap_Vulnerabity', tfin);

%  Equilibrium point
N_1 = 10; N_2 = 10; 
n1 = 1:0.5:26;
n2 = n1;
c1 = 1; c2 = 1;
[X, Y] = meshgrid(n1, n2);

%% Define the Lyapounov function
V = c1*(X-N_1-N_1*log(X/N_1))+c2*(Y-N_2-N_2*log(Y/N_2));

%% Figures
figure(1)
set(1,'Position',[20 38 500 300])
plot(t,x1,'b', t,x2,':r')
set(gca, 'FontName','Arial', 'FontSize',12)
xlabel('time')
ylabel('Populations')
legend('Species 1', 'Species 2')

figure(2)
set(2,'Position',[538 38 500 300])
surf(n1, n2, V)
set(gca, 'FontName','Arial', 'FontSize',12)
shading interp
axis(axis)
rotate3d on
hold on
V_pp = c1*(x1-N_1-N_1*log(x1/N_1)) + c2*(x2-N_2-N_2*log(x2/N_2));
plot3(x1, x2, V_pp, 'y')
view([78, 30])
rotate3d on
xlabel('x_2')
ylabel('x_1')
zlabel('Lyapounov function')

figure(3)
set(3,'Position',[20 430 500 300])
contour(n1,n2,V,[1 2 3 4])
set(gca, 'FontName','Arial', 'FontSize',12)
hold on
plot(x1, x2, ':r')
plot(N_1, N_2, 'ob')
ylabel('x_2')
xlabel('x_1')

figure(4)
set(4,'Position',[538 430 500 300])
plot(V_pp)
set(gca, 'FontName','Arial', 'FontSize',12)
xlabel('Steps')
ylabel('Lyapounov function')