% ********************************************************
% 
% Environmental Systems Analysis with Matlab 
% S. Marsili-Libelli
%
%  CRC Press 2016
% ISBN 9781498706353
% Matlab code revised by Emanuele El Basri and Giacomo Barni
% ********************************************************
%
% Demonstration of the proportional harvesting 
% for non-depensated populations
% 
% Sect. 5.3.2
% 
% ********************************************************

clear
close all
clc

r = 0.3;
K = 50;
x0 = 0.5;
frac_K = 0.75;    % Harvest as a fraction of K (75%)

x=0:K/20:K;
dx=r*x.*(1-x./K);
g=r*(1-frac_K);
yg=g*x;
x_star=K*(1-g/r); % Population of equilibrium
Yield=g*x_star;   % Yield

%% Simulation
tend=100;
[t,xsim,y]=sim('harvest_g',[0 tend]);

%% Figures
figure(1)
set(1,'Position',[18 40 560 420])
set(gca,'FontName','Arial','FontSize',12)
plot(x,dx)
hold on
fprintf(['harvest rate g = ',num2str(g),'\n'])
plot(x,yg,':r')
hold on
plot(x_star,Yield,'or','MarkerFaceColor','r','MarkerSize',6)
plot([x_star x_star],[0 Yield],':r')
text(x_star,Yield,['   K_h_a_r_v = ',num2str(x_star)],'verticalAlignment','top')
xlabel('Population')
ylabel('Growth rate')
legend('Rate','harvest','location','south','orientation','horizontal')

figure(2)
set(2,'Position',[598 39 560 420])
set(gca,'FontName','Arial','FontSize',12)
plot(t,pop)
hold on
g=0;% Simulate the no-harvest situation for comparison
[t,xsim,y]=sim('harvest_g',[0 tend]);
plot(t,pop,':r')
plot([0 tend],[x_star x_star],':k')
xlabel('time')
ylabel('Population')
title('Development of the proportionally harvested population')
legend('Harvested population','Unexploited population','Harvested carrying capacity','location','southeast')